
// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#include <sbkpep.h>
#include <sbkpepbuffer.h>

#define PYSIDE6_COMOPT_COMPRESS 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "akonadicalendar_python.h"

// main header
#include "akonadi_standardcalendaractionmanager_wrapper.h"

// Wrappers providing overrides
#include "akonadi_todopurger_wrapper.h"

// Argument includes
#include <QList>
#include <QStringList>
#include <akonadi/collection.h>
#include <akonadi/item.h>
#include <qaction.h>
#include <qitemselectionmodel.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <standardcalendaractionmanager.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Akonadi;

extern "C" {
static PyTypeObject *Sbk_Akonadi_StandardCalendarActionManager_TypeF(void)
{
    return SbkAkonadiCalendarTypeStructs[SBK_Akonadi_StandardCalendarActionManager_IDX].type;
}
} // extern "C"

// Native ---------------------------------------------------------

void StandardCalendarActionManagerWrapper::resetPyMethodCache()
{
    std::fill(m_PyMethodCache.begin(), m_PyMethodCache.end(), nullptr);
}

void StandardCalendarActionManagerWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_StandardCalendarActionManager_TypeF(), gil, funcName, m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    TodoPurgerWrapper::sbk_o_childEvent("StandardCalendarActionManager", funcName, gil, pyOverride, event);
}

void StandardCalendarActionManagerWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_StandardCalendarActionManager_TypeF(), gil, funcName, m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    TodoPurgerWrapper::sbk_o_connectNotify("StandardCalendarActionManager", funcName, gil, pyOverride, signal);
}

void StandardCalendarActionManagerWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_StandardCalendarActionManager_TypeF(), gil, funcName, m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    TodoPurgerWrapper::sbk_o_customEvent("StandardCalendarActionManager", funcName, gil, pyOverride, event);
}

void StandardCalendarActionManagerWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_StandardCalendarActionManager_TypeF(), gil, funcName, m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    TodoPurgerWrapper::sbk_o_connectNotify("StandardCalendarActionManager", funcName, gil, pyOverride, signal);
}

bool StandardCalendarActionManagerWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_StandardCalendarActionManager_TypeF(), gil, funcName, m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return TodoPurgerWrapper::sbk_o_event("StandardCalendarActionManager", funcName, gil, pyOverride, event);
}

bool StandardCalendarActionManagerWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_StandardCalendarActionManager_TypeF(), gil, funcName, m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return TodoPurgerWrapper::sbk_o_eventFilter("StandardCalendarActionManager", funcName, gil, pyOverride, watched, event);
}

void StandardCalendarActionManagerWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_StandardCalendarActionManager_TypeF(), gil, funcName, m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    TodoPurgerWrapper::sbk_o_timerEvent("StandardCalendarActionManager", funcName, gil, pyOverride, event);
}

const QMetaObject *StandardCalendarActionManagerWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return Akonadi::StandardCalendarActionManager::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int StandardCalendarActionManagerWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = Akonadi::StandardCalendarActionManager::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *StandardCalendarActionManagerWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    if (SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this)) {
        auto *obSelf = reinterpret_cast<PyObject *>(pySelf);
        if (PySide::inherits(Py_TYPE(obSelf), _clname))
            return static_cast<void *>(const_cast< StandardCalendarActionManagerWrapper *>(this));
    }
    return Akonadi::StandardCalendarActionManager::qt_metacast(_clname);
}

StandardCalendarActionManagerWrapper::~StandardCalendarActionManagerWrapper()
{
    auto *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this, Sbk_Akonadi_StandardCalendarActionManager_TypeF());
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int Sbk_Akonadi_StandardCalendarActionManager_Init(PyObject *, PyObject *, PyObject *)
{
    Shiboken::Errors::setInstantiateNonConstructible("StandardCalendarActionManager");
    return -1;
}

static PyObject *Sbk_Akonadi_StandardCalendarActionManagerFunc_action(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::StandardCalendarActionManager *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_StandardCalendarActionManager_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: StandardCalendarActionManager::action(Akonadi::StandardCalendarActionManager::Type)const->QAction*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_StandardCalendarActionManager_Type_IDX]))), (pyArg)))) {
        overloadId = 0; // StandardCalendarActionManager::action(Akonadi::StandardCalendarActionManager::Type)const->QAction*
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "action", SbkAkonadiCalendarTypeStructs[SBK_Akonadi_StandardCalendarActionManager_IDX]);

    // Call function/method
    {
        ::Akonadi::StandardCalendarActionManager::Type cppArg0 = static_cast< ::Akonadi::StandardCalendarActionManager::Type>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // StandardCalendarActionManager::action(Akonadi::StandardCalendarActionManager::Type)const->QAction*
            QAction * cppResult = const_cast<const ::Akonadi::StandardCalendarActionManager *>(cppSelf)->action(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAction_IDX]), cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_StandardCalendarActionManagerFunc_createAction(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::StandardCalendarActionManager *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_StandardCalendarActionManager_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: StandardCalendarActionManager::createAction(Akonadi::StandardCalendarActionManager::Type)->QAction*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_StandardCalendarActionManager_Type_IDX]))), (pyArg)))) {
        overloadId = 0; // StandardCalendarActionManager::createAction(Akonadi::StandardCalendarActionManager::Type)->QAction*
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "createAction", SbkAkonadiCalendarTypeStructs[SBK_Akonadi_StandardCalendarActionManager_IDX]);

    // Call function/method
    {
        ::Akonadi::StandardCalendarActionManager::Type cppArg0 = static_cast< ::Akonadi::StandardCalendarActionManager::Type>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // StandardCalendarActionManager::createAction(Akonadi::StandardCalendarActionManager::Type)->QAction*
            QAction * cppResult = cppSelf->createAction(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAction_IDX]), cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_StandardCalendarActionManagerFunc_createAllActions(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::StandardCalendarActionManager *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_StandardCalendarActionManager_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // StandardCalendarActionManager::createAllActions()
        cppSelf->createAllActions();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_StandardCalendarActionManagerFunc_interceptAction(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::StandardCalendarActionManager *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_StandardCalendarActionManager_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "interceptAction", errInfo, SbkAkonadiCalendarTypeStructs[SBK_Akonadi_StandardCalendarActionManager_IDX]);

    if (PyArg_ParseTuple(args, "|OO:interceptAction", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: StandardCalendarActionManager::interceptAction(Akonadi::StandardCalendarActionManager::Type,bool=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_StandardCalendarActionManager_Type_IDX]))), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // interceptAction(Akonadi::StandardCalendarActionManager::Type,bool)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
            overloadId = 0; // StandardCalendarActionManager::interceptAction(Akonadi::StandardCalendarActionManager::Type,bool=)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "interceptAction", SbkAkonadiCalendarTypeStructs[SBK_Akonadi_StandardCalendarActionManager_IDX]);

    // Call function/method
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"intercept", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !((pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "interceptAction", errInfo, SbkAkonadiCalendarTypeStructs[SBK_Akonadi_StandardCalendarActionManager_IDX]);
            }
        }
        ::Akonadi::StandardCalendarActionManager::Type cppArg0 = static_cast< ::Akonadi::StandardCalendarActionManager::Type>(0);
        pythonToCpp[0](pyArgs[0], &cppArg0);
        bool cppArg1 = true;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // StandardCalendarActionManager::interceptAction(Akonadi::StandardCalendarActionManager::Type,bool=)
            cppSelf->interceptAction(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_StandardCalendarActionManagerFunc_selectedCollections(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::StandardCalendarActionManager *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_StandardCalendarActionManager_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // StandardCalendarActionManager::selectedCollections()const->QList<Akonadi::Collection>
        QList<Akonadi::Collection> cppResult = const_cast<const ::Akonadi::StandardCalendarActionManager *>(cppSelf)->selectedCollections();
        pyResult = Shiboken::Conversions::copyToPython(SbkAkonadiCalendarTypeConverters[SBK_AkonadiCalendar_QList_Akonadi_Collection_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_StandardCalendarActionManagerFunc_selectedItems(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::StandardCalendarActionManager *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_StandardCalendarActionManager_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // StandardCalendarActionManager::selectedItems()const->QList<Akonadi::Item>
        QList<Akonadi::Item> cppResult = const_cast<const ::Akonadi::StandardCalendarActionManager *>(cppSelf)->selectedItems();
        pyResult = Shiboken::Conversions::copyToPython(SbkAkonadiCalendarTypeConverters[SBK_AkonadiCalendar_QList_Akonadi_Item_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_StandardCalendarActionManagerFunc_setCollectionPropertiesPageNames(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::StandardCalendarActionManager *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_StandardCalendarActionManager_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: StandardCalendarActionManager::setCollectionPropertiesPageNames(const QStringList&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 0; // StandardCalendarActionManager::setCollectionPropertiesPageNames(const QStringList&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCollectionPropertiesPageNames", SbkAkonadiCalendarTypeStructs[SBK_Akonadi_StandardCalendarActionManager_IDX]);

    // Call function/method
    {
        ::QStringList cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // StandardCalendarActionManager::setCollectionPropertiesPageNames(const QStringList&)
            cppSelf->setCollectionPropertiesPageNames(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_StandardCalendarActionManagerFunc_setCollectionSelectionModel(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::StandardCalendarActionManager *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_StandardCalendarActionManager_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: StandardCalendarActionManager::setCollectionSelectionModel(QItemSelectionModel*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelectionModel_IDX]), (pyArg)))) {
        overloadId = 0; // StandardCalendarActionManager::setCollectionSelectionModel(QItemSelectionModel*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCollectionSelectionModel", SbkAkonadiCalendarTypeStructs[SBK_Akonadi_StandardCalendarActionManager_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QItemSelectionModel *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // StandardCalendarActionManager::setCollectionSelectionModel(QItemSelectionModel*)
            cppSelf->setCollectionSelectionModel(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_StandardCalendarActionManagerFunc_setItemSelectionModel(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::StandardCalendarActionManager *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_StandardCalendarActionManager_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: StandardCalendarActionManager::setItemSelectionModel(QItemSelectionModel*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QItemSelectionModel_IDX]), (pyArg)))) {
        overloadId = 0; // StandardCalendarActionManager::setItemSelectionModel(QItemSelectionModel*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setItemSelectionModel", SbkAkonadiCalendarTypeStructs[SBK_Akonadi_StandardCalendarActionManager_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QItemSelectionModel *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // StandardCalendarActionManager::setItemSelectionModel(QItemSelectionModel*)
            cppSelf->setItemSelectionModel(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_Akonadi_StandardCalendarActionManager_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_Akonadi_StandardCalendarActionManager_EnumFlagInfo[] = {
    "Type:IntEnum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_Akonadi_StandardCalendarActionManager_methods[] = {
    {"action", reinterpret_cast<PyCFunction>(Sbk_Akonadi_StandardCalendarActionManagerFunc_action), METH_O, nullptr},
    {"createAction", reinterpret_cast<PyCFunction>(Sbk_Akonadi_StandardCalendarActionManagerFunc_createAction), METH_O, nullptr},
    {"createAllActions", reinterpret_cast<PyCFunction>(Sbk_Akonadi_StandardCalendarActionManagerFunc_createAllActions), METH_NOARGS, nullptr},
    {"interceptAction", reinterpret_cast<PyCFunction>(Sbk_Akonadi_StandardCalendarActionManagerFunc_interceptAction), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"selectedCollections", reinterpret_cast<PyCFunction>(Sbk_Akonadi_StandardCalendarActionManagerFunc_selectedCollections), METH_NOARGS, nullptr},
    {"selectedItems", reinterpret_cast<PyCFunction>(Sbk_Akonadi_StandardCalendarActionManagerFunc_selectedItems), METH_NOARGS, nullptr},
    {"setCollectionPropertiesPageNames", reinterpret_cast<PyCFunction>(Sbk_Akonadi_StandardCalendarActionManagerFunc_setCollectionPropertiesPageNames), METH_O, nullptr},
    {"setCollectionSelectionModel", reinterpret_cast<PyCFunction>(Sbk_Akonadi_StandardCalendarActionManagerFunc_setCollectionSelectionModel), METH_O, nullptr},
    {"setItemSelectionModel", reinterpret_cast<PyCFunction>(Sbk_Akonadi_StandardCalendarActionManagerFunc_setItemSelectionModel), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Akonadi_StandardCalendarActionManager_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Akonadi::StandardCalendarActionManager *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_StandardCalendarActionManager_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<StandardCalendarActionManagerWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Akonadi_StandardCalendarActionManager_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Akonadi_StandardCalendarActionManager_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}

// Class Definition -----------------------------------------------
extern "C" {

static PyType_Slot Sbk_Akonadi_StandardCalendarActionManager_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Akonadi_StandardCalendarActionManager_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Akonadi_StandardCalendarActionManager_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Akonadi_StandardCalendarActionManager_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Akonadi_StandardCalendarActionManager_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Akonadi_StandardCalendarActionManager_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkDummyNew /* PYSIDE-595: Prevent replacement of "0" with base->tp_new. */)},
    {0, nullptr}
};
static PyType_Spec Sbk_Akonadi_StandardCalendarActionManager_spec = {
    "1:AkonadiCalendar.Akonadi.StandardCalendarActionManager",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Akonadi_StandardCalendarActionManager_slots
};

} //extern "C"

static void *Sbk_Akonadi_StandardCalendarActionManager_typeDiscovery([[maybe_unused]] void *cptr, [[maybe_unused]] PyTypeObject *instanceType)
{
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::Akonadi::StandardCalendarActionManager *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_Akonadi_StandardCalendarActionManager_Type(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Akonadi::StandardCalendarActionManager::Type>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Akonadi::StandardCalendarActionManager::Type *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Akonadi_StandardCalendarActionManager_Type_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_StandardCalendarActionManager_Type_IDX])))
        return Enum_PythonToCpp_Akonadi_StandardCalendarActionManager_Type;
    return {};
}

static PyObject *Akonadi_StandardCalendarActionManager_Type_CppToPython_Enum(PyTypeObject *pyType, const void *cppIn)
{
    using IntType = std::underlying_type_t<::Akonadi::StandardCalendarActionManager::Type>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Akonadi::StandardCalendarActionManager::Type *>(cppIn));
    return Shiboken::Enum::newItem(pyType, castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void StandardCalendarActionManager_PythonToCpp_StandardCalendarActionManager_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Akonadi_StandardCalendarActionManager_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_StandardCalendarActionManager_PythonToCpp_StandardCalendarActionManager_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Akonadi_StandardCalendarActionManager_TypeF()))
        return StandardCalendarActionManager_PythonToCpp_StandardCalendarActionManager_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *StandardCalendarActionManager_PTR_CppToPython_StandardCalendarActionManager(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::Akonadi::StandardCalendarActionManager *>(const_cast<void *>(cppIn)), Sbk_Akonadi_StandardCalendarActionManager_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Akonadi_StandardCalendarActionManager_SignatureStrings[] = {
    "AkonadiCalendar.Akonadi.StandardCalendarActionManager.action(self,type:AkonadiCalendar.Akonadi.StandardCalendarActionManager.Type)->PySide6.QtGui.QAction",
    "AkonadiCalendar.Akonadi.StandardCalendarActionManager.createAction(self,type:AkonadiCalendar.Akonadi.StandardCalendarActionManager.Type)->PySide6.QtGui.QAction",
    "AkonadiCalendar.Akonadi.StandardCalendarActionManager.createAllActions(self)",
    "AkonadiCalendar.Akonadi.StandardCalendarActionManager.interceptAction(self,type:AkonadiCalendar.Akonadi.StandardCalendarActionManager.Type,intercept:bool=true)",
    "AkonadiCalendar.Akonadi.StandardCalendarActionManager.selectedCollections(self)->QList[AkonadiCore.Akonadi.Collection]",
    "AkonadiCalendar.Akonadi.StandardCalendarActionManager.selectedItems(self)->QList[AkonadiCore.Akonadi.Item]",
    "AkonadiCalendar.Akonadi.StandardCalendarActionManager.setCollectionPropertiesPageNames(self,names:QStringList)",
    "AkonadiCalendar.Akonadi.StandardCalendarActionManager.setCollectionSelectionModel(self,selectionModel:PySide6.QtCore.QItemSelectionModel)",
    "AkonadiCalendar.Akonadi.StandardCalendarActionManager.setItemSelectionModel(self,selectionModel:PySide6.QtCore.QItemSelectionModel)",
    nullptr}; // Sentinel
#else
static constexpr size_t Akonadi_StandardCalendarActionManager_SignatureByteSize = 241;
static constexpr uint8_t Akonadi_StandardCalendarActionManager_SignatureBytes[241] = {
    0x78, 0xda, 0xcd, 0x92, 0x31, 0x6b, 0xc3, 0x30, 0x10, 0x85, 0xf7, 0xfe, 0x92, 0x1a, 0x1c, 0x8d,
    0x1d, 0x0c, 0x0d, 0x88, 0x0c, 0xa1, 0xd0, 0x14, 0x0b, 0x77, 0x2b, 0x1d, 0x54, 0xeb, 0x35, 0x88,
    0x28, 0x92, 0x39, 0x5d, 0x86, 0xfc, 0xfb, 0x5a, 0x56, 0x13, 0x13, 0xba, 0x04, 0x25, 0x43, 0xb7,
    0x3b, 0xdd, 0xdd, 0x7b, 0xdf, 0x03, 0xc9, 0x5d, 0xf0, 0xda, 0xd8, 0x95, 0x76, 0xf0, 0x46, 0x93,
    0x90, 0xb9, 0x17, 0x1d, 0xeb, 0xd4, 0x9b, 0xd3, 0x40, 0xf6, 0x6c, 0x83, 0xdf, 0x68, 0xaf, 0xb7,
    0x20, 0xa1, 0xa7, 0xee, 0x31, 0xc2, 0x7d, 0xd7, 0x7c, 0x1c, 0xd0, 0xc8, 0x22, 0x99, 0xf7, 0xf1,
    0xb4, 0x5a, 0x2c, 0xdb, 0x63, 0x67, 0x0d, 0x9e, 0x84, 0xe2, 0xf5, 0xc1, 0x0a, 0x95, 0x77, 0x1e,
    0xca, 0x24, 0x7b, 0x82, 0x66, 0xc8, 0xff, 0xce, 0xe7, 0x5c, 0x7e, 0x8e, 0x13, 0x63, 0x55, 0x28,
    0x66, 0x3d, 0x83, 0x7a, 0x0c, 0x7c, 0xc7, 0xbc, 0xf5, 0x59, 0xb4, 0xf9, 0x0a, 0xc1, 0x3d, 0x33,
    0x1d, 0x50, 0xca, 0x37, 0xf2, 0xa0, 0x67, 0x98, 0x55, 0x70, 0xa9, 0x98, 0xf3, 0x2e, 0x96, 0xea,
    0xd5, 0x46, 0xfe, 0x38, 0xc9, 0x06, 0xc2, 0x59, 0x72, 0x5e, 0xfe, 0xbc, 0xd1, 0xf6, 0x85, 0xb1,
    0xbf, 0xc2, 0x30, 0xad, 0x95, 0x5b, 0xf1, 0xcc, 0xdb, 0x52, 0x18, 0x40, 0x6c, 0x11, 0xdb, 0x71,
    0xf8, 0xa6, 0xf7, 0xc8, 0xee, 0xb5, 0x4f, 0x65, 0xa3, 0x3a, 0x26, 0xeb, 0xb7, 0x89, 0xa3, 0xba,
    0x87, 0x5d, 0x87, 0xdf, 0x62, 0x13, 0x0c, 0x5c, 0x76, 0x8a, 0x17, 0x6f, 0xcd, 0xfc, 0x73, 0xa7,
    0xc4, 0x2a, 0x45, 0xbd, 0x3c, 0xbb, 0x81, 0xe4, 0xaf, 0x58, 0x31, 0xc3, 0x0f, 0x93, 0xfa, 0xb2,
    0xcf
};
#endif

PyTypeObject *init_Akonadi_StandardCalendarActionManager(PyObject *enclosingClass)
{
    auto &typeStruct = SbkAkonadiCalendarTypeStructs[SBK_Akonadi_StandardCalendarActionManager_IDX];
    if (typeStruct.type != nullptr)
        return typeStruct.type;

    auto *base1 = reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]));
    Shiboken::AutoDecRef Sbk_Akonadi_StandardCalendarActionManager_Type_bases(PyTuple_Pack(1, base1));

    PyTypeObject *pyType = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "StandardCalendarActionManager",
        "Akonadi::StandardCalendarActionManager*",
        &Sbk_Akonadi_StandardCalendarActionManager_spec,
        &Shiboken::callCppDestructor< Akonadi::StandardCalendarActionManager >,
        Sbk_Akonadi_StandardCalendarActionManager_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Akonadi_StandardCalendarActionManager_SignatureStrings);
#else
    InitSignatureBytes(pyType, Akonadi_StandardCalendarActionManager_SignatureBytes, Akonadi_StandardCalendarActionManager_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Akonadi_StandardCalendarActionManager_PropertyStrings);
    typeStruct.type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        StandardCalendarActionManager_PythonToCpp_StandardCalendarActionManager_PTR,
        is_StandardCalendarActionManager_PythonToCpp_StandardCalendarActionManager_PTR_Convertible,
        StandardCalendarActionManager_PTR_CppToPython_StandardCalendarActionManager);

    Shiboken::Conversions::registerConverterName(converter, "Akonadi::StandardCalendarActionManager");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::StandardCalendarActionManager*");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::StandardCalendarActionManager&");
    Shiboken::Conversions::registerConverterAlias(converter, "StandardCalendarActionManager");
    Shiboken::Conversions::registerConverterAlias(converter, "StandardCalendarActionManager*");
    Shiboken::Conversions::registerConverterAlias(converter, "StandardCalendarActionManager&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Akonadi::StandardCalendarActionManager).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(StandardCalendarActionManagerWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(pyType, &Sbk_Akonadi_StandardCalendarActionManager_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_Akonadi_StandardCalendarActionManager_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    [[maybe_unused]] PyTypeObject *EType{};

    // Initialization of enum 'Type'.
    const char *Type_Initializer[] = {
        "CreateEvent",
        "CreateTodo",
        "CreateSubTodo",
        "CreateJournal",
        "EditIncidence",
        "LastType",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Type_InitializerValues[] = {
        uint8_t(Akonadi::StandardCalendarActionManager::Type::CreateEvent),   //  0x27  39
        uint8_t(Akonadi::StandardCalendarActionManager::Type::CreateTodo),    //  0x28  40
        uint8_t(Akonadi::StandardCalendarActionManager::Type::CreateSubTodo), //  0x29  41
        uint8_t(Akonadi::StandardCalendarActionManager::Type::CreateJournal), //  0x2a  42
        uint8_t(Akonadi::StandardCalendarActionManager::Type::EditIncidence), //  0x2b  43
        uint8_t(Akonadi::StandardCalendarActionManager::Type::LastType)       //  0x2c  44
        };
    EType = Shiboken::Enum::createPythonEnum(pyType,
        "1:AkonadiCalendar.Akonadi.StandardCalendarActionManager.Type",
        Type_Initializer, Type_InitializerValues);
    SbkAkonadiCalendarTypeStructs[SBK_Akonadi_StandardCalendarActionManager_Type_IDX].type = EType;
    // Register converter for enum 'Akonadi::StandardCalendarActionManager::Type'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Akonadi_StandardCalendarActionManager_Type_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Akonadi_StandardCalendarActionManager_Type,
            is_Enum_PythonToCpp_Akonadi_StandardCalendarActionManager_Type_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Akonadi::StandardCalendarActionManager::Type");
        Shiboken::Conversions::registerConverterAlias(converter, "StandardCalendarActionManager::Type");
        Shiboken::Conversions::registerConverterAlias(converter, "Type");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Type' enum.

    PySide::Signal::registerSignals(pyType, &::Akonadi::StandardCalendarActionManager::staticMetaObject);
    qRegisterMetaType< ::Akonadi::StandardCalendarActionManager::Type >("StandardCalendarActionManager::Type");
    qRegisterMetaType< ::Akonadi::StandardCalendarActionManager::Type >("Akonadi::StandardCalendarActionManager::Type");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::Akonadi::StandardCalendarActionManager::staticMetaObject, sizeof(StandardCalendarActionManagerWrapper));

    return pyType;
}
