
// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#include <sbkpep.h>
#include <sbkpepbuffer.h>

#define PYSIDE6_COMOPT_COMPRESS 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "akonadicalendar_python.h"

// main header
#include "akonadi_incidencechanger_wrapper.h"

// Wrappers providing overrides
#include "akonadi_todopurger_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <akonadi/collection.h>
#include <akonadi/entitytreemodel.h>
#include <akonadi/item.h>
#include <history.h>
#include <incidencechanger.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qwidget.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Akonadi;

extern "C" {
static PyTypeObject *Sbk_Akonadi_IncidenceChanger_TypeF(void)
{
    return SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX].type;
}
} // extern "C"

// Native ---------------------------------------------------------

void IncidenceChangerWrapper::resetPyMethodCache()
{
    std::fill(m_PyMethodCache.begin(), m_PyMethodCache.end(), nullptr);
}

IncidenceChangerWrapper::IncidenceChangerWrapper(::QObject * parent) : Akonadi::IncidenceChanger(parent)
{
}

void IncidenceChangerWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_IncidenceChanger_TypeF(), gil, funcName, m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    TodoPurgerWrapper::sbk_o_childEvent("IncidenceChanger", funcName, gil, pyOverride, event);
}

void IncidenceChangerWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_IncidenceChanger_TypeF(), gil, funcName, m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    TodoPurgerWrapper::sbk_o_connectNotify("IncidenceChanger", funcName, gil, pyOverride, signal);
}

void IncidenceChangerWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_IncidenceChanger_TypeF(), gil, funcName, m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    TodoPurgerWrapper::sbk_o_customEvent("IncidenceChanger", funcName, gil, pyOverride, event);
}

void IncidenceChangerWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_IncidenceChanger_TypeF(), gil, funcName, m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    TodoPurgerWrapper::sbk_o_connectNotify("IncidenceChanger", funcName, gil, pyOverride, signal);
}

bool IncidenceChangerWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_IncidenceChanger_TypeF(), gil, funcName, m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return TodoPurgerWrapper::sbk_o_event("IncidenceChanger", funcName, gil, pyOverride, event);
}

bool IncidenceChangerWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_IncidenceChanger_TypeF(), gil, funcName, m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return TodoPurgerWrapper::sbk_o_eventFilter("IncidenceChanger", funcName, gil, pyOverride, watched, event);
}

void IncidenceChangerWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_IncidenceChanger_TypeF(), gil, funcName, m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    TodoPurgerWrapper::sbk_o_timerEvent("IncidenceChanger", funcName, gil, pyOverride, event);
}

const QMetaObject *IncidenceChangerWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return Akonadi::IncidenceChanger::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int IncidenceChangerWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = Akonadi::IncidenceChanger::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *IncidenceChangerWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    if (SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this)) {
        auto *obSelf = reinterpret_cast<PyObject *>(pySelf);
        if (PySide::inherits(Py_TYPE(obSelf), _clname))
            return static_cast<void *>(const_cast< IncidenceChangerWrapper *>(this));
    }
    return Akonadi::IncidenceChanger::qt_metacast(_clname);
}

IncidenceChangerWrapper::~IncidenceChangerWrapper()
{
    auto *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this, Sbk_Akonadi_IncidenceChanger_TypeF());
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Akonadi_IncidenceChanger_Init(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Akonadi::IncidenceChanger >()))
        return -1;

    IncidenceChangerWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:IncidenceChanger", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: IncidenceChanger::IncidenceChanger(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // IncidenceChanger(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // IncidenceChanger::IncidenceChanger(QObject*=)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]);

    // Resolve keyword arguments
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !((pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]);
            }
        }
    }

    // PyMI support
    [[maybe_unused]] const bool usesPyMI = Shiboken::callInheritedInit(self, args, errInfo.isNull() ? kwds : errInfo.object(), SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceChanger::IncidenceChanger(QObject*=)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) IncidenceChangerWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new IncidenceChangerWrapper(cppArg0);
            }

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< Akonadi::IncidenceChanger >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]);
    };


    return 1;
}

static PyObject *Sbk_Akonadi_IncidenceChangerFunc_autoAdjustRecurrence(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::IncidenceChanger *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // IncidenceChanger::autoAdjustRecurrence()const->bool
        bool cppResult = const_cast<const ::Akonadi::IncidenceChanger *>(cppSelf)->autoAdjustRecurrence();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_IncidenceChangerFunc_createFromItem(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::IncidenceChanger *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "createFromItem", errInfo, SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:createFromItem", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: IncidenceChanger::createFromItem(const Akonadi::Item&,const Akonadi::Collection&=,QWidget*=)->int
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // createFromItem(Akonadi::Item,Akonadi::Collection,QWidget*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // createFromItem(Akonadi::Item,Akonadi::Collection,QWidget*)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[2])))) {
                overloadId = 0; // IncidenceChanger::createFromItem(const Akonadi::Item&,const Akonadi::Collection&=,QWidget*=)->int
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "createFromItem", SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]);

    // Call function/method
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[2] = {{"collection", 1}, {"parent", 2}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 2, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !((pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), (pyArgs[1])))))
                || (pyArgs[2] != nullptr && !((pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[2])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "createFromItem", errInfo, SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::Akonadi::Item cppArg0_local;
        ::Akonadi::Item *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::Akonadi::Collection cppArg1_local = Akonadi::Collection();
        ::Akonadi::Collection *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1]) {
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);
            }
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QWidget *cppArg2 = nullptr;
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceChanger::createFromItem(const Akonadi::Item&,const Akonadi::Collection&=,QWidget*=)->int
            int cppResult = cppSelf->createFromItem(*cppArg0, *cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_IncidenceChangerFunc_defaultCollection(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::IncidenceChanger *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // IncidenceChanger::defaultCollection()const->Akonadi::Collection
        Akonadi::Collection cppResult = const_cast<const ::Akonadi::IncidenceChanger *>(cppSelf)->defaultCollection();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_IncidenceChangerFunc_deleteIncidence(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::IncidenceChanger *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "deleteIncidence", errInfo, SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]);

    if (PyArg_ParseTuple(args, "|OO:deleteIncidence", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: IncidenceChanger::deleteIncidence(const Akonadi::Item&,QWidget*=)->int
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // deleteIncidence(Akonadi::Item,QWidget*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[1])))) {
            overloadId = 0; // IncidenceChanger::deleteIncidence(const Akonadi::Item&,QWidget*=)->int
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "deleteIncidence", SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]);

    // Call function/method
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !((pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[1])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "deleteIncidence", errInfo, SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::Akonadi::Item cppArg0_local;
        ::Akonadi::Item *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QWidget *cppArg1 = nullptr;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceChanger::deleteIncidence(const Akonadi::Item&,QWidget*=)->int
            int cppResult = cppSelf->deleteIncidence(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_IncidenceChangerFunc_deleteIncidences(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::IncidenceChanger *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "deleteIncidences", errInfo, SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]);

    if (PyArg_ParseTuple(args, "|OO:deleteIncidences", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: IncidenceChanger::deleteIncidences(const QList<Akonadi::Item>&,QWidget*=)->int
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkAkonadiCalendarTypeConverters[SBK_AkonadiCalendar_QList_Akonadi_Item_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // deleteIncidences(QList<Akonadi::Item>,QWidget*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[1])))) {
            overloadId = 0; // IncidenceChanger::deleteIncidences(const QList<Akonadi::Item>&,QWidget*=)->int
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "deleteIncidences", SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]);

    // Call function/method
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !((pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[1])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "deleteIncidences", errInfo, SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]);
            }
        }
        ::QList<Akonadi::Item> cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QWidget *cppArg1 = nullptr;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceChanger::deleteIncidences(const QList<Akonadi::Item>&,QWidget*=)->int
            int cppResult = cppSelf->deleteIncidences(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_IncidenceChangerFunc_deletedRecently(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::IncidenceChanger *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: IncidenceChanger::deletedRecently(long long)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<long long>(), (pyArg)))) {
        overloadId = 0; // IncidenceChanger::deletedRecently(long long)const->bool
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "deletedRecently", SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]);

    // Call function/method
    {
        long long cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceChanger::deletedRecently(long long)const->bool
            bool cppResult = const_cast<const ::Akonadi::IncidenceChanger *>(cppSelf)->deletedRecently(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_IncidenceChangerFunc_destinationPolicy(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::IncidenceChanger *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // IncidenceChanger::destinationPolicy()const->Akonadi::IncidenceChanger::DestinationPolicy
        Akonadi::IncidenceChanger::DestinationPolicy cppResult = const_cast<const ::Akonadi::IncidenceChanger *>(cppSelf)->destinationPolicy();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_DestinationPolicy_IDX]))), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_IncidenceChangerFunc_endAtomicOperation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::IncidenceChanger *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // IncidenceChanger::endAtomicOperation()
        cppSelf->endAtomicOperation();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_IncidenceChangerFunc_entityTreeModel(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::IncidenceChanger *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // IncidenceChanger::entityTreeModel()const->Akonadi::EntityTreeModel*
        Akonadi::EntityTreeModel * cppResult = const_cast<const ::Akonadi::IncidenceChanger *>(cppSelf)->entityTreeModel();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]), cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_IncidenceChangerFunc_groupwareCommunication(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::IncidenceChanger *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // IncidenceChanger::groupwareCommunication()const->bool
        bool cppResult = const_cast<const ::Akonadi::IncidenceChanger *>(cppSelf)->groupwareCommunication();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_IncidenceChangerFunc_history(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::IncidenceChanger *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // IncidenceChanger::history()const->Akonadi::History*
        Akonadi::History * cppResult = const_cast<const ::Akonadi::IncidenceChanger *>(cppSelf)->history();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_History_IDX]), cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_IncidenceChangerFunc_historyEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::IncidenceChanger *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // IncidenceChanger::historyEnabled()const->bool
        bool cppResult = const_cast<const ::Akonadi::IncidenceChanger *>(cppSelf)->historyEnabled();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_IncidenceChangerFunc_invitationPolicy(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::IncidenceChanger *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // IncidenceChanger::invitationPolicy()const->Akonadi::IncidenceChanger::InvitationPolicy
        Akonadi::IncidenceChanger::InvitationPolicy cppResult = const_cast<const ::Akonadi::IncidenceChanger *>(cppSelf)->invitationPolicy();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_InvitationPolicy_IDX]))), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_IncidenceChangerFunc_lastCollectionUsed(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::IncidenceChanger *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // IncidenceChanger::lastCollectionUsed()const->Akonadi::Collection
        Akonadi::Collection cppResult = const_cast<const ::Akonadi::IncidenceChanger *>(cppSelf)->lastCollectionUsed();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_IncidenceChangerFunc_modifyIncidence(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::IncidenceChanger *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: IncidenceChanger::modifyIncidence(const Akonadi::Item&)->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), (pyArg)))) {
        overloadId = 0; // IncidenceChanger::modifyIncidence(const Akonadi::Item&)->int
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "modifyIncidence", SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Akonadi::Item cppArg0_local;
        ::Akonadi::Item *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceChanger::modifyIncidence(const Akonadi::Item&)->int
            int cppResult = cppSelf->modifyIncidence(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_IncidenceChangerFunc_respectsCollectionRights(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::IncidenceChanger *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // IncidenceChanger::respectsCollectionRights()const->bool
        bool cppResult = const_cast<const ::Akonadi::IncidenceChanger *>(cppSelf)->respectsCollectionRights();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_IncidenceChangerFunc_setAutoAdjustRecurrence(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::IncidenceChanger *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: IncidenceChanger::setAutoAdjustRecurrence(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // IncidenceChanger::setAutoAdjustRecurrence(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAutoAdjustRecurrence", SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceChanger::setAutoAdjustRecurrence(bool)
            cppSelf->setAutoAdjustRecurrence(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_IncidenceChangerFunc_setDefaultCollection(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::IncidenceChanger *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: IncidenceChanger::setDefaultCollection(const Akonadi::Collection&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Collection_IDX]), (pyArg)))) {
        overloadId = 0; // IncidenceChanger::setDefaultCollection(const Akonadi::Collection&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDefaultCollection", SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Akonadi::Collection cppArg0_local;
        ::Akonadi::Collection *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceChanger::setDefaultCollection(const Akonadi::Collection&)
            cppSelf->setDefaultCollection(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_IncidenceChangerFunc_setDestinationPolicy(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::IncidenceChanger *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: IncidenceChanger::setDestinationPolicy(Akonadi::IncidenceChanger::DestinationPolicy)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_DestinationPolicy_IDX]))), (pyArg)))) {
        overloadId = 0; // IncidenceChanger::setDestinationPolicy(Akonadi::IncidenceChanger::DestinationPolicy)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDestinationPolicy", SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]);

    // Call function/method
    {
        ::Akonadi::IncidenceChanger::DestinationPolicy cppArg0{Akonadi::IncidenceChanger::DestinationPolicyDefault};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceChanger::setDestinationPolicy(Akonadi::IncidenceChanger::DestinationPolicy)
            cppSelf->setDestinationPolicy(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_IncidenceChangerFunc_setEntityTreeModel(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::IncidenceChanger *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: IncidenceChanger::setEntityTreeModel(Akonadi::EntityTreeModel*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_EntityTreeModel_IDX]), (pyArg)))) {
        overloadId = 0; // IncidenceChanger::setEntityTreeModel(Akonadi::EntityTreeModel*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setEntityTreeModel", SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::Akonadi::EntityTreeModel *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceChanger::setEntityTreeModel(Akonadi::EntityTreeModel*)
            cppSelf->setEntityTreeModel(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_IncidenceChangerFunc_setGroupwareCommunication(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::IncidenceChanger *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: IncidenceChanger::setGroupwareCommunication(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // IncidenceChanger::setGroupwareCommunication(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setGroupwareCommunication", SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceChanger::setGroupwareCommunication(bool)
            cppSelf->setGroupwareCommunication(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_IncidenceChangerFunc_setHistoryEnabled(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::IncidenceChanger *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: IncidenceChanger::setHistoryEnabled(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // IncidenceChanger::setHistoryEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setHistoryEnabled", SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceChanger::setHistoryEnabled(bool)
            cppSelf->setHistoryEnabled(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_IncidenceChangerFunc_setInvitationPolicy(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::IncidenceChanger *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: IncidenceChanger::setInvitationPolicy(Akonadi::IncidenceChanger::InvitationPolicy)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_InvitationPolicy_IDX]))), (pyArg)))) {
        overloadId = 0; // IncidenceChanger::setInvitationPolicy(Akonadi::IncidenceChanger::InvitationPolicy)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setInvitationPolicy", SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]);

    // Call function/method
    {
        ::Akonadi::IncidenceChanger::InvitationPolicy cppArg0{Akonadi::IncidenceChanger::InvitationPolicySend};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceChanger::setInvitationPolicy(Akonadi::IncidenceChanger::InvitationPolicy)
            cppSelf->setInvitationPolicy(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_IncidenceChangerFunc_setRespectsCollectionRights(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::IncidenceChanger *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: IncidenceChanger::setRespectsCollectionRights(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // IncidenceChanger::setRespectsCollectionRights(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRespectsCollectionRights", SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceChanger::setRespectsCollectionRights(bool)
            cppSelf->setRespectsCollectionRights(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_IncidenceChangerFunc_setShowDialogsOnError(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::IncidenceChanger *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: IncidenceChanger::setShowDialogsOnError(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // IncidenceChanger::setShowDialogsOnError(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setShowDialogsOnError", SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceChanger::setShowDialogsOnError(bool)
            cppSelf->setShowDialogsOnError(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_IncidenceChangerFunc_showDialogsOnError(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::IncidenceChanger *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // IncidenceChanger::showDialogsOnError()const->bool
        bool cppResult = const_cast<const ::Akonadi::IncidenceChanger *>(cppSelf)->showDialogsOnError();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_IncidenceChangerFunc_startAtomicOperation(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::IncidenceChanger *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "startAtomicOperation", errInfo, SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]);

    if (PyArg_ParseTuple(args, "|O:startAtomicOperation", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: IncidenceChanger::startAtomicOperation(const QString&=)
    if (numArgs == 0) {
        overloadId = 0; // startAtomicOperation(QString)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 0; // IncidenceChanger::startAtomicOperation(const QString&=)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "startAtomicOperation", SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]);

    // Call function/method
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"operationDescription", 0}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !((pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "startAtomicOperation", errInfo, SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]);
            }
        }
        ::QString cppArg0 = QString();
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceChanger::startAtomicOperation(const QString&=)
            cppSelf->startAtomicOperation(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_Akonadi_IncidenceChanger_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_Akonadi_IncidenceChanger_EnumFlagInfo[] = {
    "ChangeType:IntEnum",
    "DestinationPolicy:IntEnum",
    "InvitationPolicy:IntEnum",
    "InvitationPrivacy:IntEnum",
    "ResultCode:IntEnum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_Akonadi_IncidenceChanger_methods[] = {
    {"autoAdjustRecurrence", reinterpret_cast<PyCFunction>(Sbk_Akonadi_IncidenceChangerFunc_autoAdjustRecurrence), METH_NOARGS, nullptr},
    {"createFromItem", reinterpret_cast<PyCFunction>(Sbk_Akonadi_IncidenceChangerFunc_createFromItem), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"defaultCollection", reinterpret_cast<PyCFunction>(Sbk_Akonadi_IncidenceChangerFunc_defaultCollection), METH_NOARGS, nullptr},
    {"deleteIncidence", reinterpret_cast<PyCFunction>(Sbk_Akonadi_IncidenceChangerFunc_deleteIncidence), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"deleteIncidences", reinterpret_cast<PyCFunction>(Sbk_Akonadi_IncidenceChangerFunc_deleteIncidences), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"deletedRecently", reinterpret_cast<PyCFunction>(Sbk_Akonadi_IncidenceChangerFunc_deletedRecently), METH_O, nullptr},
    {"destinationPolicy", reinterpret_cast<PyCFunction>(Sbk_Akonadi_IncidenceChangerFunc_destinationPolicy), METH_NOARGS, nullptr},
    {"endAtomicOperation", reinterpret_cast<PyCFunction>(Sbk_Akonadi_IncidenceChangerFunc_endAtomicOperation), METH_NOARGS, nullptr},
    {"entityTreeModel", reinterpret_cast<PyCFunction>(Sbk_Akonadi_IncidenceChangerFunc_entityTreeModel), METH_NOARGS, nullptr},
    {"groupwareCommunication", reinterpret_cast<PyCFunction>(Sbk_Akonadi_IncidenceChangerFunc_groupwareCommunication), METH_NOARGS, nullptr},
    {"history", reinterpret_cast<PyCFunction>(Sbk_Akonadi_IncidenceChangerFunc_history), METH_NOARGS, nullptr},
    {"historyEnabled", reinterpret_cast<PyCFunction>(Sbk_Akonadi_IncidenceChangerFunc_historyEnabled), METH_NOARGS, nullptr},
    {"invitationPolicy", reinterpret_cast<PyCFunction>(Sbk_Akonadi_IncidenceChangerFunc_invitationPolicy), METH_NOARGS, nullptr},
    {"lastCollectionUsed", reinterpret_cast<PyCFunction>(Sbk_Akonadi_IncidenceChangerFunc_lastCollectionUsed), METH_NOARGS, nullptr},
    {"modifyIncidence", reinterpret_cast<PyCFunction>(Sbk_Akonadi_IncidenceChangerFunc_modifyIncidence), METH_O, nullptr},
    {"respectsCollectionRights", reinterpret_cast<PyCFunction>(Sbk_Akonadi_IncidenceChangerFunc_respectsCollectionRights), METH_NOARGS, nullptr},
    {"setAutoAdjustRecurrence", reinterpret_cast<PyCFunction>(Sbk_Akonadi_IncidenceChangerFunc_setAutoAdjustRecurrence), METH_O, nullptr},
    {"setDefaultCollection", reinterpret_cast<PyCFunction>(Sbk_Akonadi_IncidenceChangerFunc_setDefaultCollection), METH_O, nullptr},
    {"setDestinationPolicy", reinterpret_cast<PyCFunction>(Sbk_Akonadi_IncidenceChangerFunc_setDestinationPolicy), METH_O, nullptr},
    {"setEntityTreeModel", reinterpret_cast<PyCFunction>(Sbk_Akonadi_IncidenceChangerFunc_setEntityTreeModel), METH_O, nullptr},
    {"setGroupwareCommunication", reinterpret_cast<PyCFunction>(Sbk_Akonadi_IncidenceChangerFunc_setGroupwareCommunication), METH_O, nullptr},
    {"setHistoryEnabled", reinterpret_cast<PyCFunction>(Sbk_Akonadi_IncidenceChangerFunc_setHistoryEnabled), METH_O, nullptr},
    {"setInvitationPolicy", reinterpret_cast<PyCFunction>(Sbk_Akonadi_IncidenceChangerFunc_setInvitationPolicy), METH_O, nullptr},
    {"setRespectsCollectionRights", reinterpret_cast<PyCFunction>(Sbk_Akonadi_IncidenceChangerFunc_setRespectsCollectionRights), METH_O, nullptr},
    {"setShowDialogsOnError", reinterpret_cast<PyCFunction>(Sbk_Akonadi_IncidenceChangerFunc_setShowDialogsOnError), METH_O, nullptr},
    {"showDialogsOnError", reinterpret_cast<PyCFunction>(Sbk_Akonadi_IncidenceChangerFunc_showDialogsOnError), METH_NOARGS, nullptr},
    {"startAtomicOperation", reinterpret_cast<PyCFunction>(Sbk_Akonadi_IncidenceChangerFunc_startAtomicOperation), METH_VARARGS|METH_KEYWORDS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Akonadi_IncidenceChanger_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Akonadi::IncidenceChanger *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<IncidenceChangerWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Akonadi_IncidenceChanger_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Akonadi_IncidenceChanger_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}

// Class Definition -----------------------------------------------
extern "C" {

static PyType_Slot Sbk_Akonadi_IncidenceChanger_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Akonadi_IncidenceChanger_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Akonadi_IncidenceChanger_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Akonadi_IncidenceChanger_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Akonadi_IncidenceChanger_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Akonadi_IncidenceChanger_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Akonadi_IncidenceChanger_spec = {
    "1:AkonadiCalendar.Akonadi.IncidenceChanger",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Akonadi_IncidenceChanger_slots
};

} //extern "C"

static void *Sbk_Akonadi_IncidenceChanger_typeDiscovery([[maybe_unused]] void *cptr, [[maybe_unused]] PyTypeObject *instanceType)
{
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::Akonadi::IncidenceChanger *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_Akonadi_IncidenceChanger_ResultCode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Akonadi::IncidenceChanger::ResultCode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Akonadi::IncidenceChanger::ResultCode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Akonadi_IncidenceChanger_ResultCode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_ResultCode_IDX])))
        return Enum_PythonToCpp_Akonadi_IncidenceChanger_ResultCode;
    return {};
}

static PyObject *Akonadi_IncidenceChanger_ResultCode_CppToPython_Enum(PyTypeObject *pyType, const void *cppIn)
{
    using IntType = std::underlying_type_t<::Akonadi::IncidenceChanger::ResultCode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Akonadi::IncidenceChanger::ResultCode *>(cppIn));
    return Shiboken::Enum::newItem(pyType, castCppIn);

}

static void Enum_PythonToCpp_Akonadi_IncidenceChanger_DestinationPolicy(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Akonadi::IncidenceChanger::DestinationPolicy>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Akonadi::IncidenceChanger::DestinationPolicy *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Akonadi_IncidenceChanger_DestinationPolicy_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_DestinationPolicy_IDX])))
        return Enum_PythonToCpp_Akonadi_IncidenceChanger_DestinationPolicy;
    return {};
}

static PyObject *Akonadi_IncidenceChanger_DestinationPolicy_CppToPython_Enum(PyTypeObject *pyType, const void *cppIn)
{
    using IntType = std::underlying_type_t<::Akonadi::IncidenceChanger::DestinationPolicy>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Akonadi::IncidenceChanger::DestinationPolicy *>(cppIn));
    return Shiboken::Enum::newItem(pyType, castCppIn);

}

static void Enum_PythonToCpp_Akonadi_IncidenceChanger_InvitationPolicy(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Akonadi::IncidenceChanger::InvitationPolicy>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Akonadi::IncidenceChanger::InvitationPolicy *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Akonadi_IncidenceChanger_InvitationPolicy_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_InvitationPolicy_IDX])))
        return Enum_PythonToCpp_Akonadi_IncidenceChanger_InvitationPolicy;
    return {};
}

static PyObject *Akonadi_IncidenceChanger_InvitationPolicy_CppToPython_Enum(PyTypeObject *pyType, const void *cppIn)
{
    using IntType = std::underlying_type_t<::Akonadi::IncidenceChanger::InvitationPolicy>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Akonadi::IncidenceChanger::InvitationPolicy *>(cppIn));
    return Shiboken::Enum::newItem(pyType, castCppIn);

}

static void Enum_PythonToCpp_Akonadi_IncidenceChanger_InvitationPrivacy(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Akonadi::IncidenceChanger::InvitationPrivacy>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Akonadi::IncidenceChanger::InvitationPrivacy *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Akonadi_IncidenceChanger_InvitationPrivacy_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_InvitationPrivacy_IDX])))
        return Enum_PythonToCpp_Akonadi_IncidenceChanger_InvitationPrivacy;
    return {};
}

static PyObject *Akonadi_IncidenceChanger_InvitationPrivacy_CppToPython_Enum(PyTypeObject *pyType, const void *cppIn)
{
    using IntType = std::underlying_type_t<::Akonadi::IncidenceChanger::InvitationPrivacy>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Akonadi::IncidenceChanger::InvitationPrivacy *>(cppIn));
    return Shiboken::Enum::newItem(pyType, castCppIn);

}

static void Enum_PythonToCpp_Akonadi_IncidenceChanger_ChangeType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Akonadi::IncidenceChanger::ChangeType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Akonadi::IncidenceChanger::ChangeType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Akonadi_IncidenceChanger_ChangeType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_ChangeType_IDX])))
        return Enum_PythonToCpp_Akonadi_IncidenceChanger_ChangeType;
    return {};
}

static PyObject *Akonadi_IncidenceChanger_ChangeType_CppToPython_Enum(PyTypeObject *pyType, const void *cppIn)
{
    using IntType = std::underlying_type_t<::Akonadi::IncidenceChanger::ChangeType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Akonadi::IncidenceChanger::ChangeType *>(cppIn));
    return Shiboken::Enum::newItem(pyType, castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void IncidenceChanger_PythonToCpp_IncidenceChanger_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Akonadi_IncidenceChanger_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_IncidenceChanger_PythonToCpp_IncidenceChanger_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Akonadi_IncidenceChanger_TypeF()))
        return IncidenceChanger_PythonToCpp_IncidenceChanger_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *IncidenceChanger_PTR_CppToPython_IncidenceChanger(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::Akonadi::IncidenceChanger *>(const_cast<void *>(cppIn)), Sbk_Akonadi_IncidenceChanger_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Akonadi_IncidenceChanger_SignatureStrings[] = {
    "AkonadiCalendar.Akonadi.IncidenceChanger(self,parent:PySide6.QtCore.QObject=nullptr)",
    "AkonadiCalendar.Akonadi.IncidenceChanger.autoAdjustRecurrence(self)->bool",
    "AkonadiCalendar.Akonadi.IncidenceChanger.createFromItem(self,item:AkonadiCore.Akonadi.Item,collection:AkonadiCore.Akonadi.Collection=Akonadi.Collection(),parent:PySide6.QtWidgets.QWidget=nullptr)->int",
    "AkonadiCalendar.Akonadi.IncidenceChanger.defaultCollection(self)->AkonadiCore.Akonadi.Collection",
    "AkonadiCalendar.Akonadi.IncidenceChanger.deleteIncidence(self,item:AkonadiCore.Akonadi.Item,parent:PySide6.QtWidgets.QWidget=nullptr)->int",
    "AkonadiCalendar.Akonadi.IncidenceChanger.deleteIncidences(self,items:QList[AkonadiCore.Akonadi.Item],parent:PySide6.QtWidgets.QWidget=nullptr)->int",
    "AkonadiCalendar.Akonadi.IncidenceChanger.deletedRecently(self,arg__1:long long)->bool",
    "AkonadiCalendar.Akonadi.IncidenceChanger.destinationPolicy(self)->AkonadiCalendar.Akonadi.IncidenceChanger.DestinationPolicy",
    "AkonadiCalendar.Akonadi.IncidenceChanger.endAtomicOperation(self)",
    "AkonadiCalendar.Akonadi.IncidenceChanger.entityTreeModel(self)->AkonadiCore.Akonadi.EntityTreeModel",
    "AkonadiCalendar.Akonadi.IncidenceChanger.groupwareCommunication(self)->bool",
    "AkonadiCalendar.Akonadi.IncidenceChanger.history(self)->AkonadiCalendar.Akonadi.History",
    "AkonadiCalendar.Akonadi.IncidenceChanger.historyEnabled(self)->bool",
    "AkonadiCalendar.Akonadi.IncidenceChanger.invitationPolicy(self)->AkonadiCalendar.Akonadi.IncidenceChanger.InvitationPolicy",
    "AkonadiCalendar.Akonadi.IncidenceChanger.lastCollectionUsed(self)->AkonadiCore.Akonadi.Collection",
    "AkonadiCalendar.Akonadi.IncidenceChanger.modifyIncidence(self,item:AkonadiCore.Akonadi.Item)->int",
    "AkonadiCalendar.Akonadi.IncidenceChanger.respectsCollectionRights(self)->bool",
    "AkonadiCalendar.Akonadi.IncidenceChanger.setAutoAdjustRecurrence(self,enable:bool)",
    "AkonadiCalendar.Akonadi.IncidenceChanger.setDefaultCollection(self,collection:AkonadiCore.Akonadi.Collection)",
    "AkonadiCalendar.Akonadi.IncidenceChanger.setDestinationPolicy(self,destinationPolicy:AkonadiCalendar.Akonadi.IncidenceChanger.DestinationPolicy)",
    "AkonadiCalendar.Akonadi.IncidenceChanger.setEntityTreeModel(self,model:AkonadiCore.Akonadi.EntityTreeModel)",
    "AkonadiCalendar.Akonadi.IncidenceChanger.setGroupwareCommunication(self,enabled:bool)",
    "AkonadiCalendar.Akonadi.IncidenceChanger.setHistoryEnabled(self,enable:bool)",
    "AkonadiCalendar.Akonadi.IncidenceChanger.setInvitationPolicy(self,policy:AkonadiCalendar.Akonadi.IncidenceChanger.InvitationPolicy)",
    "AkonadiCalendar.Akonadi.IncidenceChanger.setRespectsCollectionRights(self,respect:bool)",
    "AkonadiCalendar.Akonadi.IncidenceChanger.setShowDialogsOnError(self,enable:bool)",
    "AkonadiCalendar.Akonadi.IncidenceChanger.showDialogsOnError(self)->bool",
    "AkonadiCalendar.Akonadi.IncidenceChanger.startAtomicOperation(self,operationDescription:QString=QString())",
    nullptr}; // Sentinel
#else
static constexpr size_t Akonadi_IncidenceChanger_SignatureByteSize = 523;
static constexpr uint8_t Akonadi_IncidenceChanger_SignatureBytes[523] = {
    0x78, 0xda, 0xb5, 0x55, 0x51, 0x6f, 0xda, 0x30, 0x10, 0x7e, 0xef, 0xaf, 0xd8, 0x23, 0x91, 0xd2,
    0x48, 0x7b, 0xe9, 0x43, 0x24, 0x2a, 0x45, 0x81, 0xad, 0x48, 0x9b, 0x68, 0x60, 0xd3, 0x1e, 0xa6,
    0xa9, 0x32, 0xf6, 0x11, 0xdc, 0x39, 0x76, 0x74, 0xbe, 0xac, 0xca, 0xbf, 0x9f, 0x03, 0x14, 0x28,
    0x04, 0x1a, 0xa7, 0xed, 0x0b, 0x38, 0x39, 0xe7, 0xbb, 0xcf, 0x77, 0xdf, 0x7d, 0x4e, 0xfe, 0x1a,
    0xcd, 0x84, 0x4c, 0x99, 0x02, 0x2d, 0x18, 0x46, 0xc9, 0xe6, 0x39, 0x9a, 0x68, 0x2e, 0x05, 0x68,
    0x0e, 0xe9, 0x8a, 0xe9, 0x1c, 0x70, 0x60, 0x41, 0x2d, 0xc3, 0x92, 0x21, 0x68, 0x8a, 0xef, 0xeb,
    0xb9, 0x0b, 0xde, 0x44, 0x19, 0xa5, 0x06, 0x21, 0xca, 0xa6, 0x8b, 0x47, 0xe0, 0x34, 0xd4, 0x95,
    0x52, 0x25, 0x61, 0x70, 0x95, 0x74, 0x04, 0x8d, 0x58, 0x45, 0x26, 0x11, 0x8f, 0x95, 0xa5, 0x19,
    0xf0, 0x0a, 0xb1, 0x89, 0xad, 0x33, 0x05, 0xd7, 0xb7, 0x0b, 0x63, 0x54, 0x77, 0x24, 0x8e, 0xc0,
    0x08, 0xbe, 0xa0, 0x29, 0x26, 0x04, 0xc5, 0x86, 0xad, 0x74, 0xab, 0xf8, 0x19, 0xa1, 0x21, 0xba,
    0xfb, 0xda, 0x05, 0x42, 0x6e, 0x94, 0x72, 0xac, 0xa5, 0xd1, 0xad, 0x7b, 0xd2, 0x5d, 0x78, 0x78,
    0xfa, 0x6a, 0x10, 0x9c, 0x96, 0xe2, 0x97, 0x14, 0x39, 0x90, 0x8d, 0xb2, 0xcd, 0x62, 0x57, 0x8d,
    0xeb, 0x5b, 0xa9, 0xa9, 0xfb, 0x41, 0x04, 0x2c, 0x59, 0xa5, 0xe8, 0x20, 0xd7, 0xb6, 0x1e, 0x97,
    0x49, 0xfa, 0x24, 0x50, 0x40, 0xb0, 0x7b, 0xdd, 0xa5, 0x54, 0x1f, 0x77, 0xd6, 0x17, 0x54, 0xec,
    0x9e, 0x8b, 0x8d, 0xb3, 0x6f, 0xd2, 0xd2, 0xef, 0x73, 0x94, 0xfe, 0x7c, 0x30, 0x27, 0xe1, 0xf4,
    0xe8, 0xe0, 0x55, 0xbd, 0xa1, 0xc4, 0x30, 0x7f, 0x78, 0xf8, 0x1c, 0x2b, 0xa3, 0xf3, 0x4f, 0xcd,
    0x8f, 0xb7, 0x3c, 0x05, 0x58, 0x92, 0x9a, 0x35, 0x9d, 0xba, 0x37, 0x4a, 0xf2, 0xfa, 0xb8, 0xab,
    0xaf, 0x22, 0x8c, 0x8e, 0x11, 0xba, 0x27, 0x77, 0xe1, 0x84, 0x4c, 0x21, 0xf9, 0xb4, 0x04, 0x64,
    0x7b, 0x4d, 0xf9, 0x20, 0x90, 0xa4, 0xfa, 0x07, 0x02, 0x7c, 0x37, 0xae, 0x40, 0x97, 0x24, 0x39,
    0x7e, 0xb9, 0xb5, 0x7b, 0x8e, 0x1c, 0x4d, 0x55, 0x3e, 0xb9, 0xae, 0xa6, 0xa6, 0x28, 0x2a, 0x2d,
    0x39, 0x3b, 0x54, 0xbf, 0x5f, 0xb9, 0x57, 0x4e, 0x3b, 0x06, 0x5f, 0x2d, 0xf2, 0xdd, 0x66, 0x9b,
    0x37, 0xee, 0x58, 0xb3, 0x85, 0x02, 0xd1, 0x8f, 0x9b, 0xd4, 0xff, 0x24, 0xbd, 0x45, 0x09, 0x93,
    0x23, 0x80, 0xee, 0xa9, 0x15, 0xb3, 0x07, 0xc6, 0xf2, 0xd3, 0xee, 0x8f, 0xf0, 0x5e, 0xe6, 0x52,
    0x18, 0x21, 0x97, 0xb5, 0x8f, 0xb9, 0xf8, 0xce, 0x27, 0x82, 0x2d, 0x1d, 0x2b, 0xbb, 0x67, 0x37,
    0x93, 0xf9, 0x8a, 0x6c, 0xbf, 0x66, 0x58, 0xa0, 0xe4, 0xdc, 0x1d, 0x14, 0xc2, 0xba, 0xcd, 0x71,
    0x83, 0x18, 0x78, 0x41, 0x8e, 0x5a, 0x3d, 0xbc, 0xfb, 0x8d, 0xe3, 0x9b, 0xad, 0xcd, 0x5b, 0xc2,
    0x13, 0xcb, 0x89, 0xfb, 0x7b, 0x8d, 0x1f, 0xa1, 0x71, 0x8b, 0x5b, 0x84, 0x45, 0xb3, 0x8c, 0x3b,
    0x38, 0x86, 0x5f, 0xae, 0xaf, 0xe7, 0x5d, 0x63, 0xdb, 0x3f, 0xd1, 0xa3, 0x81, 0x77, 0xa7, 0x73,
    0xde, 0x5f, 0x0d, 0x93, 0xb6, 0x81, 0x0f, 0x4b, 0xcf, 0x9e, 0x1c, 0xa3, 0xf8, 0x71, 0x98, 0x5d,
    0x9a, 0x9a, 0x70, 0x3b, 0x53, 0x3d, 0xce, 0x36, 0x5f, 0x99, 0xa7, 0x91, 0x64, 0xca, 0xe4, 0x76,
    0xaa, 0xc7, 0x88, 0x06, 0xdf, 0x54, 0xac, 0x76, 0x34, 0xff, 0xa9, 0x26, 0x86, 0xd4, 0x76, 0xe5,
    0x85, 0xe6, 0xf9, 0xd1, 0x49, 0x9c, 0xa3, 0x2c, 0xd7, 0xc3, 0x98, 0xcd, 0x09, 0xa5, 0xce, 0x87,
    0xdb, 0xff, 0x41, 0x10, 0x5c, 0xfd, 0x07, 0xb0, 0xfd, 0x24, 0xf1
};
#endif

PyTypeObject *init_Akonadi_IncidenceChanger(PyObject *enclosingClass)
{
    auto &typeStruct = SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX];
    if (typeStruct.type != nullptr)
        return typeStruct.type;

    auto *base1 = reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]));
    Shiboken::AutoDecRef Sbk_Akonadi_IncidenceChanger_Type_bases(PyTuple_Pack(1, base1));

    PyTypeObject *pyType = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "IncidenceChanger",
        "Akonadi::IncidenceChanger*",
        &Sbk_Akonadi_IncidenceChanger_spec,
        &Shiboken::callCppDestructor< Akonadi::IncidenceChanger >,
        Sbk_Akonadi_IncidenceChanger_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Akonadi_IncidenceChanger_SignatureStrings);
#else
    InitSignatureBytes(pyType, Akonadi_IncidenceChanger_SignatureBytes, Akonadi_IncidenceChanger_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Akonadi_IncidenceChanger_PropertyStrings);
    typeStruct.type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        IncidenceChanger_PythonToCpp_IncidenceChanger_PTR,
        is_IncidenceChanger_PythonToCpp_IncidenceChanger_PTR_Convertible,
        IncidenceChanger_PTR_CppToPython_IncidenceChanger);

    Shiboken::Conversions::registerConverterName(converter, "Akonadi::IncidenceChanger");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::IncidenceChanger*");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::IncidenceChanger&");
    Shiboken::Conversions::registerConverterAlias(converter, "IncidenceChanger");
    Shiboken::Conversions::registerConverterAlias(converter, "IncidenceChanger*");
    Shiboken::Conversions::registerConverterAlias(converter, "IncidenceChanger&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Akonadi::IncidenceChanger).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(IncidenceChangerWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(pyType, &Sbk_Akonadi_IncidenceChanger_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_Akonadi_IncidenceChanger_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    [[maybe_unused]] PyTypeObject *EType{};

    // Initialization of enum 'ResultCode'.
    const char *ResultCode_Initializer[] = {
        "ResultCodeSuccess",
        "ResultCodeJobError",
        "ResultCodeAlreadyDeleted",
        "ResultCodeInvalidDefaultCollection",
        "ResultCodeRolledback",
        "ResultCodePermissions",
        "ResultCodeUserCanceled",
        "ResultCodeInvalidUserCollection",
        "ResultCodeModificationDiscarded",
        "ResultCodeDuplicateId",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ResultCode_InitializerValues[] = {
        uint8_t(Akonadi::IncidenceChanger::ResultCode::ResultCodeSuccess),                  //  0x00  0
        uint8_t(Akonadi::IncidenceChanger::ResultCode::ResultCodeJobError),                 //  0x01  1
        uint8_t(Akonadi::IncidenceChanger::ResultCode::ResultCodeAlreadyDeleted),           //  0x02  2
        uint8_t(Akonadi::IncidenceChanger::ResultCode::ResultCodeInvalidDefaultCollection), //  0x03  3
        uint8_t(Akonadi::IncidenceChanger::ResultCode::ResultCodeRolledback),               //  0x04  4
        uint8_t(Akonadi::IncidenceChanger::ResultCode::ResultCodePermissions),              //  0x05  5
        uint8_t(Akonadi::IncidenceChanger::ResultCode::ResultCodeUserCanceled),             //  0x06  6
        uint8_t(Akonadi::IncidenceChanger::ResultCode::ResultCodeInvalidUserCollection),    //  0x07  7
        uint8_t(Akonadi::IncidenceChanger::ResultCode::ResultCodeModificationDiscarded),    //  0x08  8
        uint8_t(Akonadi::IncidenceChanger::ResultCode::ResultCodeDuplicateId)               //  0x09  9
        };
    EType = Shiboken::Enum::createPythonEnum(pyType,
        "1:AkonadiCalendar.Akonadi.IncidenceChanger.ResultCode",
        ResultCode_Initializer, ResultCode_InitializerValues);
    SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_ResultCode_IDX].type = EType;
    // Register converter for enum 'Akonadi::IncidenceChanger::ResultCode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Akonadi_IncidenceChanger_ResultCode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Akonadi_IncidenceChanger_ResultCode,
            is_Enum_PythonToCpp_Akonadi_IncidenceChanger_ResultCode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Akonadi::IncidenceChanger::ResultCode");
        Shiboken::Conversions::registerConverterAlias(converter, "IncidenceChanger::ResultCode");
        Shiboken::Conversions::registerConverterAlias(converter, "ResultCode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ResultCode' enum.

    // Initialization of enum 'DestinationPolicy'.
    const char *DestinationPolicy_Initializer[] = {
        "DestinationPolicyDefault",
        "DestinationPolicyAsk",
        "DestinationPolicyNeverAsk",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t DestinationPolicy_InitializerValues[] = {
        uint8_t(Akonadi::IncidenceChanger::DestinationPolicy::DestinationPolicyDefault), //  0x00  0
        uint8_t(Akonadi::IncidenceChanger::DestinationPolicy::DestinationPolicyAsk),     //  0x01  1
        uint8_t(Akonadi::IncidenceChanger::DestinationPolicy::DestinationPolicyNeverAsk) //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(pyType,
        "1:AkonadiCalendar.Akonadi.IncidenceChanger.DestinationPolicy",
        DestinationPolicy_Initializer, DestinationPolicy_InitializerValues);
    SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_DestinationPolicy_IDX].type = EType;
    // Register converter for enum 'Akonadi::IncidenceChanger::DestinationPolicy'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Akonadi_IncidenceChanger_DestinationPolicy_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Akonadi_IncidenceChanger_DestinationPolicy,
            is_Enum_PythonToCpp_Akonadi_IncidenceChanger_DestinationPolicy_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Akonadi::IncidenceChanger::DestinationPolicy");
        Shiboken::Conversions::registerConverterAlias(converter, "IncidenceChanger::DestinationPolicy");
        Shiboken::Conversions::registerConverterAlias(converter, "DestinationPolicy");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'DestinationPolicy' enum.

    // Initialization of enum 'InvitationPolicy'.
    const char *InvitationPolicy_Initializer[] = {
        "InvitationPolicySend",
        "InvitationPolicyAsk",
        "InvitationPolicyDontSend",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t InvitationPolicy_InitializerValues[] = {
        uint8_t(Akonadi::IncidenceChanger::InvitationPolicy::InvitationPolicySend),    //  0x00  0
        uint8_t(Akonadi::IncidenceChanger::InvitationPolicy::InvitationPolicyAsk),     //  0x01  1
        uint8_t(Akonadi::IncidenceChanger::InvitationPolicy::InvitationPolicyDontSend) //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(pyType,
        "1:AkonadiCalendar.Akonadi.IncidenceChanger.InvitationPolicy",
        InvitationPolicy_Initializer, InvitationPolicy_InitializerValues);
    SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_InvitationPolicy_IDX].type = EType;
    // Register converter for enum 'Akonadi::IncidenceChanger::InvitationPolicy'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Akonadi_IncidenceChanger_InvitationPolicy_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Akonadi_IncidenceChanger_InvitationPolicy,
            is_Enum_PythonToCpp_Akonadi_IncidenceChanger_InvitationPolicy_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Akonadi::IncidenceChanger::InvitationPolicy");
        Shiboken::Conversions::registerConverterAlias(converter, "IncidenceChanger::InvitationPolicy");
        Shiboken::Conversions::registerConverterAlias(converter, "InvitationPolicy");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'InvitationPolicy' enum.

    // Initialization of enum 'InvitationPrivacy'.
    const char *InvitationPrivacy_Initializer[] = {
        "InvitationPrivacyPlain",
        "InvitationPrivacySign",
        "InvitationPrivacyEncrypt",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t InvitationPrivacy_InitializerValues[] = {
        uint8_t(Akonadi::IncidenceChanger::InvitationPrivacy::InvitationPrivacyPlain),  //  0x00  0
        uint8_t(Akonadi::IncidenceChanger::InvitationPrivacy::InvitationPrivacySign),   //  0x01  1
        uint8_t(Akonadi::IncidenceChanger::InvitationPrivacy::InvitationPrivacyEncrypt) //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(pyType,
        "1:AkonadiCalendar.Akonadi.IncidenceChanger.InvitationPrivacy",
        InvitationPrivacy_Initializer, InvitationPrivacy_InitializerValues);
    SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_InvitationPrivacy_IDX].type = EType;
    // Register converter for enum 'Akonadi::IncidenceChanger::InvitationPrivacy'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Akonadi_IncidenceChanger_InvitationPrivacy_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Akonadi_IncidenceChanger_InvitationPrivacy,
            is_Enum_PythonToCpp_Akonadi_IncidenceChanger_InvitationPrivacy_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Akonadi::IncidenceChanger::InvitationPrivacy");
        Shiboken::Conversions::registerConverterAlias(converter, "IncidenceChanger::InvitationPrivacy");
        Shiboken::Conversions::registerConverterAlias(converter, "InvitationPrivacy");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'InvitationPrivacy' enum.

    // Initialization of enum 'ChangeType'.
    const char *ChangeType_Initializer[] = {
        "ChangeTypeCreate",
        "ChangeTypeModify",
        "ChangeTypeDelete",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ChangeType_InitializerValues[] = {
        uint8_t(Akonadi::IncidenceChanger::ChangeType::ChangeTypeCreate), //  0x00  0
        uint8_t(Akonadi::IncidenceChanger::ChangeType::ChangeTypeModify), //  0x01  1
        uint8_t(Akonadi::IncidenceChanger::ChangeType::ChangeTypeDelete)  //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(pyType,
        "1:AkonadiCalendar.Akonadi.IncidenceChanger.ChangeType",
        ChangeType_Initializer, ChangeType_InitializerValues);
    SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_ChangeType_IDX].type = EType;
    // Register converter for enum 'Akonadi::IncidenceChanger::ChangeType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Akonadi_IncidenceChanger_ChangeType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Akonadi_IncidenceChanger_ChangeType,
            is_Enum_PythonToCpp_Akonadi_IncidenceChanger_ChangeType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Akonadi::IncidenceChanger::ChangeType");
        Shiboken::Conversions::registerConverterAlias(converter, "IncidenceChanger::ChangeType");
        Shiboken::Conversions::registerConverterAlias(converter, "ChangeType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ChangeType' enum.

    PySide::Signal::registerSignals(pyType, &::Akonadi::IncidenceChanger::staticMetaObject);
    qRegisterMetaType< ::Akonadi::IncidenceChanger::ResultCode >("IncidenceChanger::ResultCode");
    qRegisterMetaType< ::Akonadi::IncidenceChanger::ResultCode >("Akonadi::IncidenceChanger::ResultCode");
    qRegisterMetaType< ::Akonadi::IncidenceChanger::DestinationPolicy >("IncidenceChanger::DestinationPolicy");
    qRegisterMetaType< ::Akonadi::IncidenceChanger::DestinationPolicy >("Akonadi::IncidenceChanger::DestinationPolicy");
    qRegisterMetaType< ::Akonadi::IncidenceChanger::InvitationPolicy >("IncidenceChanger::InvitationPolicy");
    qRegisterMetaType< ::Akonadi::IncidenceChanger::InvitationPolicy >("Akonadi::IncidenceChanger::InvitationPolicy");
    qRegisterMetaType< ::Akonadi::IncidenceChanger::InvitationPrivacy >("IncidenceChanger::InvitationPrivacy");
    qRegisterMetaType< ::Akonadi::IncidenceChanger::InvitationPrivacy >("Akonadi::IncidenceChanger::InvitationPrivacy");
    qRegisterMetaType< ::Akonadi::IncidenceChanger::ChangeType >("IncidenceChanger::ChangeType");
    qRegisterMetaType< ::Akonadi::IncidenceChanger::ChangeType >("Akonadi::IncidenceChanger::ChangeType");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::Akonadi::IncidenceChanger::staticMetaObject, sizeof(IncidenceChangerWrapper));

    return pyType;
}
