
// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#include <sbkpep.h>
#include <sbkpepbuffer.h>

#define PYSIDE6_COMOPT_COMPRESS 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "akonadicalendar_python.h"

// main header
#include "akonadi_calendarbase_wrapper.h"

// Wrappers providing overrides
#include "akonadi_calendarbase_wrapper.h"
#include "akonadi_todopurger_wrapper.h"
#include "akonadi_publishdialog_wrapper.h"

// Extra includes
#include <pysidesignal.h>

// Argument includes
#include <QList>
#include <QString>
#include <akonadi/item.h>
#include <incidencechanger.h>
#include <qdatetime.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qtimezone.h>

#include <algorithm>
#include <cctype>
#include <cstring>
#include <iterator>
#include <set>
#include <type_traits>
#include <typeinfo>

using namespace Akonadi;

extern "C" {
static PyTypeObject *Sbk_Akonadi_CalendarBase_TypeF(void)
{
    return SbkAkonadiCalendarTypeStructs[SBK_Akonadi_CalendarBase_IDX].type;
}
} // extern "C"

// Native ---------------------------------------------------------

void CalendarBaseWrapper::resetPyMethodCache()
{
    std::fill(m_PyMethodCache.begin(), m_PyMethodCache.end(), nullptr);
}

CalendarBaseWrapper::CalendarBaseWrapper(::QObject * parent) : Akonadi::CalendarBase(parent)
{
}

void CalendarBaseWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_CalendarBase_TypeF(), gil, funcName, m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    TodoPurgerWrapper::sbk_o_childEvent("CalendarBase", funcName, gil, pyOverride, event);
}

void CalendarBaseWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_CalendarBase_TypeF(), gil, funcName, m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    TodoPurgerWrapper::sbk_o_connectNotify("CalendarBase", funcName, gil, pyOverride, signal);
}

void CalendarBaseWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_CalendarBase_TypeF(), gil, funcName, m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    TodoPurgerWrapper::sbk_o_customEvent("CalendarBase", funcName, gil, pyOverride, event);
}

void CalendarBaseWrapper::customPropertyUpdate()
{
    static const char *funcName = "customPropertyUpdate";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_CalendarBase_TypeF(), gil, funcName, m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::CustomProperties::customPropertyUpdate();
    }
    PublishDialogWrapper::sbk_o_accept("CalendarBase", funcName, gil, pyOverride);
}

void CalendarBaseWrapper::customPropertyUpdated()
{
    static const char *funcName = "customPropertyUpdated";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_CalendarBase_TypeF(), gil, funcName, m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Calendar::customPropertyUpdated();
    }
    PublishDialogWrapper::sbk_o_accept("CalendarBase", funcName, gil, pyOverride);
}

void CalendarBaseWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_CalendarBase_TypeF(), gil, funcName, m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    TodoPurgerWrapper::sbk_o_connectNotify("CalendarBase", funcName, gil, pyOverride, signal);
}

void CalendarBaseWrapper::doSetTimeZone(const ::QTimeZone & timeZone)
{
    static const char *funcName = "doSetTimeZone";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_CalendarBase_TypeF(), gil, funcName, m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::MemoryCalendar::doSetTimeZone(timeZone);
    }
    sbk_o_doSetTimeZone("CalendarBase", funcName, gil, pyOverride, timeZone);
}

void CalendarBaseWrapper::sbk_o_doSetTimeZone([[maybe_unused]] const char *ownerClassName, [[maybe_unused]] const char *funcName, [[maybe_unused]] Shiboken::GilState &gil, [[maybe_unused]] const Shiboken::AutoDecRef &pyOverride, [[maybe_unused]] const ::QTimeZone & timeZone)
{
#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), &timeZone)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), &timeZone)
    ));
#endif

#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

void CalendarBaseWrapper::endBatchAdding()
{
    static const char *funcName = "endBatchAdding";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_CalendarBase_TypeF(), gil, funcName, m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::CalendarBase::endBatchAdding();
    }
    PublishDialogWrapper::sbk_o_accept("CalendarBase", funcName, gil, pyOverride);
}

bool CalendarBaseWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_CalendarBase_TypeF(), gil, funcName, m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return TodoPurgerWrapper::sbk_o_event("CalendarBase", funcName, gil, pyOverride, event);
}

bool CalendarBaseWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_CalendarBase_TypeF(), gil, funcName, m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return TodoPurgerWrapper::sbk_o_eventFilter("CalendarBase", funcName, gil, pyOverride, watched, event);
}

void CalendarBaseWrapper::incidenceUpdate(const ::QString & uid, const ::QDateTime & recurrenceId)
{
    static const char *funcName = "incidenceUpdate";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_CalendarBase_TypeF(), gil, funcName, m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::MemoryCalendar::incidenceUpdate(uid, recurrenceId);
    }
    sbk_o_incidenceUpdate("CalendarBase", funcName, gil, pyOverride, uid, recurrenceId);
}

void CalendarBaseWrapper::sbk_o_incidenceUpdate([[maybe_unused]] const char *ownerClassName, [[maybe_unused]] const char *funcName, [[maybe_unused]] Shiboken::GilState &gil, [[maybe_unused]] const Shiboken::AutoDecRef &pyOverride, [[maybe_unused]] const ::QString & uid, [[maybe_unused]] const ::QDateTime & recurrenceId)
{
#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &uid),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &recurrenceId)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &uid),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &recurrenceId)
    ));
#endif

#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

void CalendarBaseWrapper::incidenceUpdated(const ::QString & uid, const ::QDateTime & recurrenceId)
{
    static const char *funcName = "incidenceUpdated";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_CalendarBase_TypeF(), gil, funcName, m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::MemoryCalendar::incidenceUpdated(uid, recurrenceId);
    }
    CalendarBaseWrapper::sbk_o_incidenceUpdate("CalendarBase", funcName, gil, pyOverride, uid, recurrenceId);
}

void CalendarBaseWrapper::startBatchAdding()
{
    static const char *funcName = "startBatchAdding";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_CalendarBase_TypeF(), gil, funcName, m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::CalendarBase::startBatchAdding();
    }
    PublishDialogWrapper::sbk_o_accept("CalendarBase", funcName, gil, pyOverride);
}

void CalendarBaseWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_CalendarBase_TypeF(), gil, funcName, m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    TodoPurgerWrapper::sbk_o_timerEvent("CalendarBase", funcName, gil, pyOverride, event);
}

void CalendarBaseWrapper::virtual_hook(int id, void * data)
{
    static const char *funcName = "virtual_hook";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_CalendarBase_TypeF(), gil, funcName, m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::MemoryCalendar::virtual_hook(id, data);
    }
    sbk_o_virtual_hook("CalendarBase", funcName, gil, pyOverride, id, data);
}

void CalendarBaseWrapper::sbk_o_virtual_hook([[maybe_unused]] const char *ownerClassName, [[maybe_unused]] const char *funcName, [[maybe_unused]] Shiboken::GilState &gil, [[maybe_unused]] const Shiboken::AutoDecRef &pyOverride, [[maybe_unused]] int id, [[maybe_unused]] void * data)
{
#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &id),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), data)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(iN)",
        id,
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), data)
    ));
#endif

#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

const QMetaObject *CalendarBaseWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return Akonadi::CalendarBase::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int CalendarBaseWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = Akonadi::CalendarBase::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *CalendarBaseWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    if (SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this)) {
        auto *obSelf = reinterpret_cast<PyObject *>(pySelf);
        if (PySide::inherits(Py_TYPE(obSelf), _clname))
            return static_cast<void *>(const_cast< CalendarBaseWrapper *>(this));
    }
    return Akonadi::CalendarBase::qt_metacast(_clname);
}

CalendarBaseWrapper::~CalendarBaseWrapper()
{
    auto *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this, Sbk_Akonadi_CalendarBase_TypeF());
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Akonadi_CalendarBase_Init(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Akonadi::CalendarBase >()))
        return -1;

    CalendarBaseWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:CalendarBase", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: CalendarBase::CalendarBase(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // CalendarBase(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // CalendarBase::CalendarBase(QObject*=)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkAkonadiCalendarTypeStructs[SBK_Akonadi_CalendarBase_IDX]);

    // Resolve keyword arguments
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !((pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkAkonadiCalendarTypeStructs[SBK_Akonadi_CalendarBase_IDX]);
            }
        }
    }

    // PyMI support
    [[maybe_unused]] const bool usesPyMI = Shiboken::callInheritedInit(self, args, errInfo.isNull() ? kwds : errInfo.object(), SbkAkonadiCalendarTypeStructs[SBK_Akonadi_CalendarBase_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // CalendarBase::CalendarBase(QObject*=)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) CalendarBaseWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new CalendarBaseWrapper(cppArg0);
            }

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< Akonadi::CalendarBase >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkAkonadiCalendarTypeStructs[SBK_Akonadi_CalendarBase_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkAkonadiCalendarTypeStructs[SBK_Akonadi_CalendarBase_IDX]);
    };


    return 1;
}

static PyObject *Sbk_Akonadi_CalendarBaseFunc_childItems(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::CalendarBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_CalendarBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: CalendarBase::childItems(const QString&)const->QList<Akonadi::Item>
    // 1: CalendarBase::childItems(long long)const->QList<Akonadi::Item>
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<long long>(), (pyArg)))) {
        overloadId = 1; // CalendarBase::childItems(long long)const->QList<Akonadi::Item>
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // CalendarBase::childItems(const QString&)const->QList<Akonadi::Item>
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "childItems", SbkAkonadiCalendarTypeStructs[SBK_Akonadi_CalendarBase_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // childItems(const QString &parentUid) const
        {
            ::QString cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // CalendarBase::childItems(const QString&)const->QList<Akonadi::Item>
                QList<Akonadi::Item> cppResult = const_cast<const ::Akonadi::CalendarBase *>(cppSelf)->childItems(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkAkonadiCalendarTypeConverters[SBK_AkonadiCalendar_QList_Akonadi_Item_IDX], &cppResult);
            }
            break;
        }
        case 1: // childItems(long long parentId) const
        {
            long long cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // CalendarBase::childItems(long long)const->QList<Akonadi::Item>
                QList<Akonadi::Item> cppResult = const_cast<const ::Akonadi::CalendarBase *>(cppSelf)->childItems(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkAkonadiCalendarTypeConverters[SBK_AkonadiCalendar_QList_Akonadi_Item_IDX], &cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CalendarBaseFunc_endBatchAdding(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::CalendarBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_CalendarBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Calendar::endBatchAdding()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::Akonadi::CalendarBase::endBatchAdding()
            : cppSelf->endBatchAdding();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_CalendarBaseFunc_incidenceChanger(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::CalendarBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_CalendarBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // CalendarBase::incidenceChanger()const->Akonadi::IncidenceChanger*
        Akonadi::IncidenceChanger * cppResult = const_cast<const ::Akonadi::CalendarBase *>(cppSelf)->incidenceChanger();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_IncidenceChanger_IDX]), cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CalendarBaseFunc_item(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::CalendarBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_CalendarBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: CalendarBase::item(const QString&)const->Akonadi::Item
    // 1: CalendarBase::item(long long)const->Akonadi::Item
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<long long>(), (pyArg)))) {
        overloadId = 1; // CalendarBase::item(long long)const->Akonadi::Item
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // CalendarBase::item(const QString&)const->Akonadi::Item
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "item", SbkAkonadiCalendarTypeStructs[SBK_Akonadi_CalendarBase_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // item(const QString &uid) const
        {
            ::QString cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // CalendarBase::item(const QString&)const->Akonadi::Item
                Akonadi::Item cppResult = const_cast<const ::Akonadi::CalendarBase *>(cppSelf)->item(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), &cppResult);
            }
            break;
        }
        case 1: // item(long long arg__1) const
        {
            long long cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // CalendarBase::item(long long)const->Akonadi::Item
                Akonadi::Item cppResult = const_cast<const ::Akonadi::CalendarBase *>(cppSelf)->item(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Item_IDX]), &cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CalendarBaseFunc_items(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::CalendarBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_CalendarBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "items", errInfo, SbkAkonadiCalendarTypeStructs[SBK_Akonadi_CalendarBase_IDX]);

    if (PyArg_ParseTuple(args, "|O:items", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: CalendarBase::items(long long=)const->QList<Akonadi::Item>
    if (numArgs == 0) {
        overloadId = 0; // items(qlonglong)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<long long>(), (pyArgs[0])))) {
        overloadId = 0; // CalendarBase::items(long long=)const->QList<Akonadi::Item>
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "items", SbkAkonadiCalendarTypeStructs[SBK_Akonadi_CalendarBase_IDX]);

    // Call function/method
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"arg__1", 0}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !((pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<long long>(), (pyArgs[0])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "items", errInfo, SbkAkonadiCalendarTypeStructs[SBK_Akonadi_CalendarBase_IDX]);
            }
        }
        long long cppArg0 = -1;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // CalendarBase::items(long long=)const->QList<Akonadi::Item>
            QList<Akonadi::Item> cppResult = const_cast<const ::Akonadi::CalendarBase *>(cppSelf)->items(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkAkonadiCalendarTypeConverters[SBK_AkonadiCalendar_QList_Akonadi_Item_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_CalendarBaseFunc_startBatchAdding(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::CalendarBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_CalendarBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Calendar::startBatchAdding()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::Akonadi::CalendarBase::startBatchAdding()
            : cppSelf->startBatchAdding();
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_Akonadi_CalendarBase_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_Akonadi_CalendarBase_methods[] = {
    {"childItems", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CalendarBaseFunc_childItems), METH_O, nullptr},
    {"endBatchAdding", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CalendarBaseFunc_endBatchAdding), METH_NOARGS, nullptr},
    {"incidenceChanger", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CalendarBaseFunc_incidenceChanger), METH_NOARGS, nullptr},
    {"item", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CalendarBaseFunc_item), METH_O, nullptr},
    {"items", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CalendarBaseFunc_items), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"startBatchAdding", reinterpret_cast<PyCFunction>(Sbk_Akonadi_CalendarBaseFunc_startBatchAdding), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Akonadi_CalendarBase_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Akonadi::CalendarBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_CalendarBase_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<CalendarBaseWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Akonadi_CalendarBase_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Akonadi_CalendarBase_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
static void * Sbk_Akonadi_CalendarBaseSpecialCastFunction(void *obj, PyTypeObject *desiredType)
{
    auto me = reinterpret_cast< ::Akonadi::CalendarBase *>(obj);
    if (desiredType == Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_MemoryCalendar_IDX]))
        return static_cast< ::KCalendarCore::MemoryCalendar *>(me);
    else if (desiredType == Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Calendar_IDX]))
        return static_cast< ::KCalendarCore::Calendar *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))
        return static_cast< ::QObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_CustomProperties_IDX]))
        return static_cast< ::KCalendarCore::CustomProperties *>(me);
    else if (desiredType == Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IncidenceObserver_IDX]))
        return static_cast< ::KCalendarCore::IncidenceBase::IncidenceObserver *>(me);
    return me;
}



// Class Definition -----------------------------------------------
extern "C" {

static PyType_Slot Sbk_Akonadi_CalendarBase_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Akonadi_CalendarBase_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Akonadi_CalendarBase_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Akonadi_CalendarBase_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Akonadi_CalendarBase_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Akonadi_CalendarBase_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Akonadi_CalendarBase_spec = {
    "1:AkonadiCalendar.Akonadi.CalendarBase",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Akonadi_CalendarBase_slots
};

} //extern "C"

static void *Sbk_Akonadi_CalendarBase_typeDiscovery([[maybe_unused]] void *cptr, [[maybe_unused]] PyTypeObject *instanceType)
{
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::Akonadi::CalendarBase *>(reinterpret_cast< ::QObject *>(cptr));
    if (instanceType == Shiboken::SbkType< ::KCalendarCore::CustomProperties >())
        return dynamic_cast< ::Akonadi::CalendarBase *>(reinterpret_cast< ::KCalendarCore::CustomProperties *>(cptr));
    if (instanceType == Shiboken::SbkType< ::KCalendarCore::IncidenceBase::IncidenceObserver >())
        return dynamic_cast< ::Akonadi::CalendarBase *>(reinterpret_cast< ::KCalendarCore::IncidenceBase::IncidenceObserver *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void CalendarBase_PythonToCpp_CalendarBase_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Akonadi_CalendarBase_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_CalendarBase_PythonToCpp_CalendarBase_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Akonadi_CalendarBase_TypeF()))
        return CalendarBase_PythonToCpp_CalendarBase_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *CalendarBase_PTR_CppToPython_CalendarBase(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::Akonadi::CalendarBase *>(const_cast<void *>(cppIn)), Sbk_Akonadi_CalendarBase_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Akonadi_CalendarBase_SignatureStrings[] = {
    "AkonadiCalendar.Akonadi.CalendarBase(self,parent:PySide6.QtCore.QObject=nullptr)",
    "1:AkonadiCalendar.Akonadi.CalendarBase.childItems(self,parentUid:QString)->QList[AkonadiCore.Akonadi.Item]",
    "0:AkonadiCalendar.Akonadi.CalendarBase.childItems(self,parentId:long long)->QList[AkonadiCore.Akonadi.Item]",
    "AkonadiCalendar.Akonadi.CalendarBase.endBatchAdding(self)",
    "AkonadiCalendar.Akonadi.CalendarBase.incidenceChanger(self)->AkonadiCalendar.Akonadi.IncidenceChanger",
    "1:AkonadiCalendar.Akonadi.CalendarBase.item(self,uid:QString)->AkonadiCore.Akonadi.Item",
    "0:AkonadiCalendar.Akonadi.CalendarBase.item(self,arg__1:long long)->AkonadiCore.Akonadi.Item",
    "AkonadiCalendar.Akonadi.CalendarBase.items(self,arg__1:long long=-1)->QList[AkonadiCore.Akonadi.Item]",
    "AkonadiCalendar.Akonadi.CalendarBase.startBatchAdding(self)",
    nullptr}; // Sentinel
#else
static constexpr size_t Akonadi_CalendarBase_SignatureByteSize = 230;
static constexpr uint8_t Akonadi_CalendarBase_SignatureBytes[230] = {
    0x78, 0xda, 0xad, 0x91, 0x31, 0x6b, 0xc3, 0x30, 0x10, 0x85, 0x77, 0xff, 0x8a, 0x8c, 0x31, 0xc4,
    0xa2, 0x5e, 0x32, 0x18, 0x62, 0xb0, 0x3d, 0x19, 0x02, 0xad, 0x09, 0x99, 0x4a, 0x09, 0x57, 0xe9,
    0x6a, 0xab, 0x55, 0xce, 0x41, 0xba, 0x0c, 0xf9, 0xf7, 0xb1, 0x6b, 0x4c, 0xe3, 0xb4, 0x06, 0x41,
    0xb3, 0x08, 0xe9, 0xd0, 0xfb, 0x1e, 0xef, 0x5d, 0xf6, 0xd5, 0x12, 0x28, 0x5d, 0x80, 0x41, 0x52,
    0x60, 0x45, 0x36, 0xbc, 0xc5, 0x38, 0xc8, 0xc1, 0xe1, 0xd2, 0xa1, 0xf9, 0x58, 0x9d, 0xc0, 0x22,
    0x71, 0xf2, 0x72, 0xd9, 0x69, 0x85, 0x6b, 0x51, 0x71, 0xd1, 0x5a, 0x14, 0xd5, 0xf3, 0xfb, 0x27,
    0x4a, 0xde, 0xd0, 0xd9, 0x98, 0x13, 0xdb, 0x30, 0x88, 0x93, 0xcc, 0x03, 0x29, 0x64, 0xa3, 0x8d,
    0x2a, 0x19, 0x8f, 0xee, 0x96, 0xbe, 0xd7, 0x2a, 0xa9, 0x76, 0x6c, 0x35, 0xd5, 0x61, 0x94, 0x56,
    0x5b, 0xed, 0xf8, 0x75, 0xc4, 0xf5, 0x6e, 0x23, 0xaa, 0x17, 0xbe, 0x05, 0x4f, 0xff, 0xb1, 0x2a,
    0x55, 0x62, 0x5a, 0xaa, 0x17, 0xfd, 0xe1, 0xe1, 0xe5, 0xe5, 0xd4, 0xdd, 0x72, 0x60, 0xd9, 0x64,
    0x4a, 0x75, 0x09, 0xbe, 0xdd, 0x42, 0x3f, 0xa5, 0x26, 0xd9, 0xb5, 0x4a, 0x12, 0x8b, 0x06, 0xa8,
    0x46, 0x3b, 0x68, 0xa3, 0x74, 0x4e, 0x5c, 0xde, 0xfd, 0xf7, 0xad, 0x5d, 0x77, 0x61, 0x86, 0x16,
    0xce, 0x93, 0xaa, 0xe7, 0x82, 0xfb, 0x76, 0xfc, 0xc3, 0x05, 0x5b, 0x1f, 0x0e, 0xf1, 0xa4, 0xdb,
    0x59, 0xb8, 0x37, 0xda, 0xfd, 0xcd, 0xde, 0x44, 0xf1, 0xa3, 0x56, 0xe7, 0x18, 0x2c, 0xff, 0x5e,
    0xde, 0x15, 0xfd, 0x81, 0x21, 0x62
};
#endif

PyTypeObject *init_Akonadi_CalendarBase(PyObject *enclosingClass)
{
    auto &typeStruct = SbkAkonadiCalendarTypeStructs[SBK_Akonadi_CalendarBase_IDX];
    if (typeStruct.type != nullptr)
        return typeStruct.type;

    auto *base1 = reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_MemoryCalendar_IDX]));
    Shiboken::AutoDecRef Sbk_Akonadi_CalendarBase_Type_bases(PyTuple_Pack(1, base1));

    PyTypeObject *pyType = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "CalendarBase",
        "Akonadi::CalendarBase*",
        &Sbk_Akonadi_CalendarBase_spec,
        &Shiboken::callCppDestructor< Akonadi::CalendarBase >,
        Sbk_Akonadi_CalendarBase_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Akonadi_CalendarBase_SignatureStrings);
#else
    InitSignatureBytes(pyType, Akonadi_CalendarBase_SignatureBytes, Akonadi_CalendarBase_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Akonadi_CalendarBase_PropertyStrings);
    typeStruct.type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        CalendarBase_PythonToCpp_CalendarBase_PTR,
        is_CalendarBase_PythonToCpp_CalendarBase_PTR_Convertible,
        CalendarBase_PTR_CppToPython_CalendarBase);

    Shiboken::Conversions::registerConverterName(converter, "Akonadi::CalendarBase");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::CalendarBase*");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::CalendarBase&");
    Shiboken::Conversions::registerConverterAlias(converter, "CalendarBase");
    Shiboken::Conversions::registerConverterAlias(converter, "CalendarBase*");
    Shiboken::Conversions::registerConverterAlias(converter, "CalendarBase&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Akonadi::CalendarBase).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(CalendarBaseWrapper).name());

    MultipleInheritanceInitFunction func = Shiboken::ObjectType::getMultipleInheritanceFunction(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Calendar_IDX]));
    Shiboken::ObjectType::setMultipleInheritanceFunction(Sbk_Akonadi_CalendarBase_TypeF(), func);
    Shiboken::ObjectType::setCastFunction(Sbk_Akonadi_CalendarBase_TypeF(), &Sbk_Akonadi_CalendarBaseSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(pyType, &Sbk_Akonadi_CalendarBase_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::Akonadi::CalendarBase::staticMetaObject);
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::Akonadi::CalendarBase::staticMetaObject, sizeof(CalendarBaseWrapper));

    return pyType;
}
