
// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#include <sbkpep.h>
#include <sbkpepbuffer.h>

#define PYSIDE6_COMOPT_COMPRESS 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "akonadicalendar_python.h"

// main header
#include "akonadi_itiphandler_wrapper.h"

// Wrappers providing overrides
#include "akonadi_todopurger_wrapper.h"

// Argument includes
#include <QString>
#include <itiphandler.h>
#include <qobject.h>
#include <qobjectdefs.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Akonadi;

extern "C" {
static PyTypeObject *Sbk_Akonadi_ITIPHandler_TypeF(void)
{
    return SbkAkonadiCalendarTypeStructs[SBK_Akonadi_ITIPHandler_IDX].type;
}
} // extern "C"

// Native ---------------------------------------------------------

void ITIPHandlerWrapper::resetPyMethodCache()
{
    std::fill(m_PyMethodCache.begin(), m_PyMethodCache.end(), nullptr);
}

ITIPHandlerWrapper::ITIPHandlerWrapper(::QObject * parent) : Akonadi::ITIPHandler(parent)
{
}

void ITIPHandlerWrapper::childEvent(::QChildEvent * event)
{
    static const char *funcName = "childEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_ITIPHandler_TypeF(), gil, funcName, m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::childEvent(event);
    }
    TodoPurgerWrapper::sbk_o_childEvent("ITIPHandler", funcName, gil, pyOverride, event);
}

void ITIPHandlerWrapper::connectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "connectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_ITIPHandler_TypeF(), gil, funcName, m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::connectNotify(signal);
    }
    TodoPurgerWrapper::sbk_o_connectNotify("ITIPHandler", funcName, gil, pyOverride, signal);
}

void ITIPHandlerWrapper::customEvent(::QEvent * event)
{
    static const char *funcName = "customEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_ITIPHandler_TypeF(), gil, funcName, m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::customEvent(event);
    }
    TodoPurgerWrapper::sbk_o_customEvent("ITIPHandler", funcName, gil, pyOverride, event);
}

void ITIPHandlerWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    static const char *funcName = "disconnectNotify";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_ITIPHandler_TypeF(), gil, funcName, m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::disconnectNotify(signal);
    }
    TodoPurgerWrapper::sbk_o_connectNotify("ITIPHandler", funcName, gil, pyOverride, signal);
}

bool ITIPHandlerWrapper::event(::QEvent * event)
{
    static const char *funcName = "event";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_ITIPHandler_TypeF(), gil, funcName, m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::event(event);
    }
    return TodoPurgerWrapper::sbk_o_event("ITIPHandler", funcName, gil, pyOverride, event);
}

bool ITIPHandlerWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    static const char *funcName = "eventFilter";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_ITIPHandler_TypeF(), gil, funcName, m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::eventFilter(watched, event);
    }
    return TodoPurgerWrapper::sbk_o_eventFilter("ITIPHandler", funcName, gil, pyOverride, watched, event);
}

void ITIPHandlerWrapper::timerEvent(::QTimerEvent * event)
{
    static const char *funcName = "timerEvent";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_ITIPHandler_TypeF(), gil, funcName, m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::QObject::timerEvent(event);
    }
    TodoPurgerWrapper::sbk_o_timerEvent("ITIPHandler", funcName, gil, pyOverride, event);
}

const QMetaObject *ITIPHandlerWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return Akonadi::ITIPHandler::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int ITIPHandlerWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = Akonadi::ITIPHandler::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *ITIPHandlerWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    if (SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this)) {
        auto *obSelf = reinterpret_cast<PyObject *>(pySelf);
        if (PySide::inherits(Py_TYPE(obSelf), _clname))
            return static_cast<void *>(const_cast< ITIPHandlerWrapper *>(this));
    }
    return Akonadi::ITIPHandler::qt_metacast(_clname);
}

ITIPHandlerWrapper::~ITIPHandlerWrapper()
{
    auto *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this, Sbk_Akonadi_ITIPHandler_TypeF());
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Akonadi_ITIPHandler_Init(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Akonadi::ITIPHandler >()))
        return -1;

    ITIPHandlerWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:ITIPHandler", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: ITIPHandler::ITIPHandler(QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // ITIPHandler(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // ITIPHandler::ITIPHandler(QObject*=)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkAkonadiCalendarTypeStructs[SBK_Akonadi_ITIPHandler_IDX]);

    // Resolve keyword arguments
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"parent", 0}};
            if (!Shiboken::parseConstructorKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !((pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkAkonadiCalendarTypeStructs[SBK_Akonadi_ITIPHandler_IDX]);
            }
        }
    }

    // PyMI support
    [[maybe_unused]] const bool usesPyMI = Shiboken::callInheritedInit(self, args, errInfo.isNull() ? kwds : errInfo.object(), SbkAkonadiCalendarTypeStructs[SBK_Akonadi_ITIPHandler_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // ITIPHandler::ITIPHandler(QObject*=)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) ITIPHandlerWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new ITIPHandlerWrapper(cppArg0);
            }

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< Akonadi::ITIPHandler >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", SbkAkonadiCalendarTypeStructs[SBK_Akonadi_ITIPHandler_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkAkonadiCalendarTypeStructs[SBK_Akonadi_ITIPHandler_IDX]);
    };


    return 1;
}

static PyObject *Sbk_Akonadi_ITIPHandlerFunc_processiTIPMessage(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::ITIPHandler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_ITIPHandler_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "processiTIPMessage", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: ITIPHandler::processiTIPMessage(const QString&,const QString&,const QString&)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
        overloadId = 0; // ITIPHandler::processiTIPMessage(const QString&,const QString&,const QString&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "processiTIPMessage", SbkAkonadiCalendarTypeStructs[SBK_Akonadi_ITIPHandler_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QString cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // ITIPHandler::processiTIPMessage(const QString&,const QString&,const QString&)
            cppSelf->processiTIPMessage(cppArg0, cppArg1, cppArg2);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_ITIPHandlerFunc_setShowDialogsOnError(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::ITIPHandler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_ITIPHandler_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: ITIPHandler::setShowDialogsOnError(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // ITIPHandler::setShowDialogsOnError(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setShowDialogsOnError", SbkAkonadiCalendarTypeStructs[SBK_Akonadi_ITIPHandler_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // ITIPHandler::setShowDialogsOnError(bool)
            cppSelf->setShowDialogsOnError(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_Akonadi_ITIPHandler_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_Akonadi_ITIPHandler_EnumFlagInfo[] = {
    "Result:IntEnum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_Akonadi_ITIPHandler_methods[] = {
    {"processiTIPMessage", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ITIPHandlerFunc_processiTIPMessage), METH_VARARGS, nullptr},
    {"setShowDialogsOnError", reinterpret_cast<PyCFunction>(Sbk_Akonadi_ITIPHandlerFunc_setShowDialogsOnError), METH_O, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Akonadi_ITIPHandler_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Akonadi::ITIPHandler *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_ITIPHandler_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<ITIPHandlerWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Akonadi_ITIPHandler_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Akonadi_ITIPHandler_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}

// Class Definition -----------------------------------------------
extern "C" {

static PyType_Slot Sbk_Akonadi_ITIPHandler_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Akonadi_ITIPHandler_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Akonadi_ITIPHandler_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Akonadi_ITIPHandler_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Akonadi_ITIPHandler_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Akonadi_ITIPHandler_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Akonadi_ITIPHandler_spec = {
    "1:AkonadiCalendar.Akonadi.ITIPHandler",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Akonadi_ITIPHandler_slots
};

} //extern "C"

static void *Sbk_Akonadi_ITIPHandler_typeDiscovery([[maybe_unused]] void *cptr, [[maybe_unused]] PyTypeObject *instanceType)
{
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::Akonadi::ITIPHandler *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_Akonadi_ITIPHandler_Result(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::Akonadi::ITIPHandler::Result>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::Akonadi::ITIPHandler::Result *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_Akonadi_ITIPHandler_Result_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_ITIPHandler_Result_IDX])))
        return Enum_PythonToCpp_Akonadi_ITIPHandler_Result;
    return {};
}

static PyObject *Akonadi_ITIPHandler_Result_CppToPython_Enum(PyTypeObject *pyType, const void *cppIn)
{
    using IntType = std::underlying_type_t<::Akonadi::ITIPHandler::Result>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::Akonadi::ITIPHandler::Result *>(cppIn));
    return Shiboken::Enum::newItem(pyType, castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void ITIPHandler_PythonToCpp_ITIPHandler_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Akonadi_ITIPHandler_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_ITIPHandler_PythonToCpp_ITIPHandler_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Akonadi_ITIPHandler_TypeF()))
        return ITIPHandler_PythonToCpp_ITIPHandler_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *ITIPHandler_PTR_CppToPython_ITIPHandler(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::Akonadi::ITIPHandler *>(const_cast<void *>(cppIn)), Sbk_Akonadi_ITIPHandler_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Akonadi_ITIPHandler_SignatureStrings[] = {
    "AkonadiCalendar.Akonadi.ITIPHandler(self,parent:PySide6.QtCore.QObject=nullptr)",
    "AkonadiCalendar.Akonadi.ITIPHandler.processiTIPMessage(self,receiver:QString,iCal:QString,action:QString)",
    "AkonadiCalendar.Akonadi.ITIPHandler.setShowDialogsOnError(self,enable:bool)",
    nullptr}; // Sentinel
#else
static constexpr size_t Akonadi_ITIPHandler_SignatureByteSize = 158;
static constexpr uint8_t Akonadi_ITIPHandler_SignatureBytes[158] = {
    0x78, 0xda, 0x8d, 0x8f, 0xb1, 0x0e, 0x82, 0x40, 0x10, 0x44, 0x7b, 0xbe, 0x44, 0x12, 0x72, 0xa5,
    0x05, 0x09, 0x05, 0x41, 0x13, 0x29, 0x0c, 0x10, 0xfc, 0x81, 0xe5, 0x6e, 0xc5, 0xd3, 0xcd, 0x2e,
    0xd9, 0x3b, 0x35, 0xfe, 0xbd, 0x18, 0xd4, 0x56, 0xab, 0xc9, 0x9b, 0xe2, 0x4d, 0xa6, 0xbc, 0x08,
    0x83, 0xf3, 0x15, 0x10, 0xb2, 0x03, 0x35, 0xe5, 0xc2, 0xa6, 0x3e, 0xd4, 0xed, 0x0e, 0xd8, 0x11,
    0xea, 0x2a, 0x20, 0x1d, 0xb3, 0x09, 0x14, 0x39, 0xe6, 0xed, 0xa3, 0xf7, 0x0e, 0xd7, 0xa6, 0x8b,
    0x95, 0x28, 0x9a, 0xae, 0x19, 0xce, 0x68, 0x63, 0xc1, 0x57, 0xa2, 0x29, 0x6a, 0x9a, 0x94, 0xbf,
    0x7d, 0x66, 0x52, 0xb1, 0x18, 0x82, 0x9f, 0xab, 0xfd, 0x9c, 0x30, 0xe2, 0x32, 0xa1, 0x68, 0xd1,
    0xdf, 0x50, 0xf3, 0xae, 0x8f, 0xea, 0x79, 0xcc, 0x5e, 0x9a, 0x2f, 0x80, 0x8d, 0x5e, 0xf8, 0x83,
    0xff, 0x2d, 0x05, 0x8c, 0xfd, 0x49, 0xee, 0x1b, 0x0f, 0x24, 0x63, 0x68, 0x78, 0xab, 0x2a, 0xef,
    0x3f, 0xc8, 0x30, 0x10, 0xe6, 0x83, 0x08, 0xa5, 0xc9, 0x13, 0x3f, 0xae, 0x5f, 0xe8
};
#endif

PyTypeObject *init_Akonadi_ITIPHandler(PyObject *enclosingClass)
{
    auto &typeStruct = SbkAkonadiCalendarTypeStructs[SBK_Akonadi_ITIPHandler_IDX];
    if (typeStruct.type != nullptr)
        return typeStruct.type;

    auto *base1 = reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]));
    Shiboken::AutoDecRef Sbk_Akonadi_ITIPHandler_Type_bases(PyTuple_Pack(1, base1));

    PyTypeObject *pyType = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "ITIPHandler",
        "Akonadi::ITIPHandler*",
        &Sbk_Akonadi_ITIPHandler_spec,
        &Shiboken::callCppDestructor< Akonadi::ITIPHandler >,
        Sbk_Akonadi_ITIPHandler_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Akonadi_ITIPHandler_SignatureStrings);
#else
    InitSignatureBytes(pyType, Akonadi_ITIPHandler_SignatureBytes, Akonadi_ITIPHandler_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Akonadi_ITIPHandler_PropertyStrings);
    typeStruct.type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        ITIPHandler_PythonToCpp_ITIPHandler_PTR,
        is_ITIPHandler_PythonToCpp_ITIPHandler_PTR_Convertible,
        ITIPHandler_PTR_CppToPython_ITIPHandler);

    Shiboken::Conversions::registerConverterName(converter, "Akonadi::ITIPHandler");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::ITIPHandler*");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::ITIPHandler&");
    Shiboken::Conversions::registerConverterAlias(converter, "ITIPHandler");
    Shiboken::Conversions::registerConverterAlias(converter, "ITIPHandler*");
    Shiboken::Conversions::registerConverterAlias(converter, "ITIPHandler&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Akonadi::ITIPHandler).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(ITIPHandlerWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(pyType, &Sbk_Akonadi_ITIPHandler_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_Akonadi_ITIPHandler_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    [[maybe_unused]] PyTypeObject *EType{};

    // Initialization of enum 'Result'.
    const char *Result_Initializer[] = {
        "ResultError",
        "ResultSuccess",
        "ResultCancelled",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Result_InitializerValues[] = {
        uint8_t(Akonadi::ITIPHandler::Result::ResultError),    //  0x00  0
        uint8_t(Akonadi::ITIPHandler::Result::ResultSuccess),  //  0x01  1
        uint8_t(Akonadi::ITIPHandler::Result::ResultCancelled) //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(pyType,
        "1:AkonadiCalendar.Akonadi.ITIPHandler.Result",
        Result_Initializer, Result_InitializerValues);
    SbkAkonadiCalendarTypeStructs[SBK_Akonadi_ITIPHandler_Result_IDX].type = EType;
    // Register converter for enum 'Akonadi::ITIPHandler::Result'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            Akonadi_ITIPHandler_Result_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_Akonadi_ITIPHandler_Result,
            is_Enum_PythonToCpp_Akonadi_ITIPHandler_Result_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "Akonadi::ITIPHandler::Result");
        Shiboken::Conversions::registerConverterAlias(converter, "ITIPHandler::Result");
        Shiboken::Conversions::registerConverterAlias(converter, "Result");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Result' enum.

    PySide::Signal::registerSignals(pyType, &::Akonadi::ITIPHandler::staticMetaObject);
    qRegisterMetaType< ::Akonadi::ITIPHandler::Result >("ITIPHandler::Result");
    qRegisterMetaType< ::Akonadi::ITIPHandler::Result >("Akonadi::ITIPHandler::Result");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::Akonadi::ITIPHandler::staticMetaObject, sizeof(ITIPHandlerWrapper));

    return pyType;
}
