
// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#include <sbkpep.h>
#include <sbkpepbuffer.h>

#define PYSIDE6_COMOPT_COMPRESS 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "akonadicalendar_python.h"

// main header
#include "akonadi_blockalarmsattribute_wrapper.h"

// Wrappers providing overrides
#include "akonadi_blockalarmsattribute_wrapper.h"

// Argument includes
#include <blockalarmsattribute.h>
#include <kcalendarcore/alarm.h>
#include <qbytearray.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace Akonadi;

extern "C" {
static PyTypeObject *Sbk_Akonadi_BlockAlarmsAttribute_TypeF(void)
{
    return SbkAkonadiCalendarTypeStructs[SBK_Akonadi_BlockAlarmsAttribute_IDX].type;
}
} // extern "C"

// Native ---------------------------------------------------------

void BlockAlarmsAttributeWrapper::resetPyMethodCache()
{
    std::fill(m_PyMethodCache.begin(), m_PyMethodCache.end(), nullptr);
}

BlockAlarmsAttributeWrapper::BlockAlarmsAttributeWrapper()
{
}

::Akonadi::BlockAlarmsAttribute * BlockAlarmsAttributeWrapper::clone() const
{
    static const char *funcName = "clone";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_BlockAlarmsAttribute_TypeF(), gil, funcName, m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::BlockAlarmsAttribute::clone();
    }
    return sbk_o_clone("BlockAlarmsAttribute", funcName, gil, pyOverride);
}

::Akonadi::BlockAlarmsAttribute * BlockAlarmsAttributeWrapper::sbk_o_clone([[maybe_unused]] const char *ownerClassName, [[maybe_unused]] const char *funcName, [[maybe_unused]] Shiboken::GilState &gil, [[maybe_unused]] const Shiboken::AutoDecRef &pyOverride)
{
#if defined(PYPY_VERSION)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION)
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_BlockAlarmsAttribute_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, PepType_GetFullyQualifiedNameStr(Shiboken::SbkType< Akonadi::BlockAlarmsAttribute >()), Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::Akonadi::BlockAlarmsAttribute *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void BlockAlarmsAttributeWrapper::deserialize(const ::QByteArray & data)
{
    static const char *funcName = "deserialize";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_BlockAlarmsAttribute_TypeF(), gil, funcName, m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::BlockAlarmsAttribute::deserialize(data);
    }
    sbk_o_deserialize("BlockAlarmsAttribute", funcName, gil, pyOverride, data);
}

void BlockAlarmsAttributeWrapper::sbk_o_deserialize([[maybe_unused]] const char *ownerClassName, [[maybe_unused]] const char *funcName, [[maybe_unused]] Shiboken::GilState &gil, [[maybe_unused]] const Shiboken::AutoDecRef &pyOverride, [[maybe_unused]] const ::QByteArray & data)
{
#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &data)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &data)
    ));
#endif

#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

::QByteArray BlockAlarmsAttributeWrapper::serialized() const
{
    static const char *funcName = "serialized";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_BlockAlarmsAttribute_TypeF(), gil, funcName, m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::BlockAlarmsAttribute::serialized();
    }
    return sbk_o_serialized("BlockAlarmsAttribute", funcName, gil, pyOverride);
}

::QByteArray BlockAlarmsAttributeWrapper::sbk_o_serialized([[maybe_unused]] const char *ownerClassName, [[maybe_unused]] const char *funcName, [[maybe_unused]] Shiboken::GilState &gil, [[maybe_unused]] const Shiboken::AutoDecRef &pyOverride)
{
#if defined(PYPY_VERSION)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION)
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, PepType_GetFullyQualifiedNameStr(Shiboken::SbkType< QByteArray >()), Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QByteArray cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QByteArray BlockAlarmsAttributeWrapper::type() const
{
    static const char *funcName = "type";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_Akonadi_BlockAlarmsAttribute_TypeF(), gil, funcName, m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::Akonadi::BlockAlarmsAttribute::type();
    }
    return BlockAlarmsAttributeWrapper::sbk_o_serialized("BlockAlarmsAttribute", funcName, gil, pyOverride);
}

BlockAlarmsAttributeWrapper::~BlockAlarmsAttributeWrapper()
{
    auto *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this, Sbk_Akonadi_BlockAlarmsAttribute_TypeF());
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Akonadi_BlockAlarmsAttribute_Init(PyObject *self, [[maybe_unused]] PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Akonadi::BlockAlarmsAttribute >()))
        return -1;

    BlockAlarmsAttributeWrapper *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkAkonadiCalendarTypeStructs[SBK_Akonadi_BlockAlarmsAttribute_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // BlockAlarmsAttribute::BlockAlarmsAttribute()
        cptr = new BlockAlarmsAttributeWrapper();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< Akonadi::BlockAlarmsAttribute >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_Akonadi_BlockAlarmsAttributeFunc_blockAlarmType(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::BlockAlarmsAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_BlockAlarmsAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "blockAlarmType", errInfo, SbkAkonadiCalendarTypeStructs[SBK_Akonadi_BlockAlarmsAttribute_IDX]);

    if (PyArg_ParseTuple(args, "|OO:blockAlarmType", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: BlockAlarmsAttribute::blockAlarmType(KCalendarCore::Alarm::Type,bool=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Alarm_Type_IDX]))), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // blockAlarmType(KCalendarCore::Alarm::Type,bool)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
            overloadId = 0; // BlockAlarmsAttribute::blockAlarmType(KCalendarCore::Alarm::Type,bool=)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "blockAlarmType", SbkAkonadiCalendarTypeStructs[SBK_Akonadi_BlockAlarmsAttribute_IDX]);

    // Call function/method
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"block", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !((pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "blockAlarmType", errInfo, SbkAkonadiCalendarTypeStructs[SBK_Akonadi_BlockAlarmsAttribute_IDX]);
            }
        }
        ::KCalendarCore::Alarm::Type cppArg0{KCalendarCore::Alarm::Invalid};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        bool cppArg1 = true;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // BlockAlarmsAttribute::blockAlarmType(KCalendarCore::Alarm::Type,bool=)
            cppSelf->blockAlarmType(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_BlockAlarmsAttributeFunc_blockEverything(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::BlockAlarmsAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_BlockAlarmsAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "blockEverything", errInfo, SbkAkonadiCalendarTypeStructs[SBK_Akonadi_BlockAlarmsAttribute_IDX]);

    if (PyArg_ParseTuple(args, "|O:blockEverything", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: BlockAlarmsAttribute::blockEverything(bool=)
    if (numArgs == 0) {
        overloadId = 0; // blockEverything(bool)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0])))) {
        overloadId = 0; // BlockAlarmsAttribute::blockEverything(bool=)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "blockEverything", SbkAkonadiCalendarTypeStructs[SBK_Akonadi_BlockAlarmsAttribute_IDX]);

    // Call function/method
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"block", 0}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !((pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "blockEverything", errInfo, SbkAkonadiCalendarTypeStructs[SBK_Akonadi_BlockAlarmsAttribute_IDX]);
            }
        }
        bool cppArg0 = true;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // BlockAlarmsAttribute::blockEverything(bool=)
            cppSelf->blockEverything(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_BlockAlarmsAttributeFunc_clone(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::BlockAlarmsAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_BlockAlarmsAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Attribute::clone()const->Akonadi::BlockAlarmsAttribute*
        Akonadi::BlockAlarmsAttribute * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::Akonadi::BlockAlarmsAttribute *>(cppSelf)->::Akonadi::BlockAlarmsAttribute::clone()
            : const_cast<const ::Akonadi::BlockAlarmsAttribute *>(cppSelf)->clone();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_BlockAlarmsAttribute_IDX]), cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_BlockAlarmsAttributeFunc_deserialize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::BlockAlarmsAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_BlockAlarmsAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Attribute::deserialize(const QByteArray&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // Attribute::deserialize(const QByteArray&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "deserialize", SbkAkonadiCalendarTypeStructs[SBK_Akonadi_BlockAlarmsAttribute_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Attribute::deserialize(const QByteArray&)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::Akonadi::BlockAlarmsAttribute::deserialize(*cppArg0)
                : cppSelf->deserialize(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_Akonadi_BlockAlarmsAttributeFunc_isAlarmTypeBlocked(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::BlockAlarmsAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_BlockAlarmsAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: BlockAlarmsAttribute::isAlarmTypeBlocked(KCalendarCore::Alarm::Type)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Alarm_Type_IDX]))), (pyArg)))) {
        overloadId = 0; // BlockAlarmsAttribute::isAlarmTypeBlocked(KCalendarCore::Alarm::Type)const->bool
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isAlarmTypeBlocked", SbkAkonadiCalendarTypeStructs[SBK_Akonadi_BlockAlarmsAttribute_IDX]);

    // Call function/method
    {
        ::KCalendarCore::Alarm::Type cppArg0{KCalendarCore::Alarm::Invalid};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // BlockAlarmsAttribute::isAlarmTypeBlocked(KCalendarCore::Alarm::Type)const->bool
            bool cppResult = const_cast<const ::Akonadi::BlockAlarmsAttribute *>(cppSelf)->isAlarmTypeBlocked(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_BlockAlarmsAttributeFunc_isEverythingBlocked(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::BlockAlarmsAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_BlockAlarmsAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // BlockAlarmsAttribute::isEverythingBlocked()const->bool
        bool cppResult = const_cast<const ::Akonadi::BlockAlarmsAttribute *>(cppSelf)->isEverythingBlocked();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_BlockAlarmsAttributeFunc_serialized(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::BlockAlarmsAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_BlockAlarmsAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Attribute::serialized()const->QByteArray
        QByteArray cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::Akonadi::BlockAlarmsAttribute *>(cppSelf)->::Akonadi::BlockAlarmsAttribute::serialized()
            : const_cast<const ::Akonadi::BlockAlarmsAttribute *>(cppSelf)->serialized();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_Akonadi_BlockAlarmsAttributeFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::Akonadi::BlockAlarmsAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_BlockAlarmsAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Attribute::type()const->QByteArray
        QByteArray cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::Akonadi::BlockAlarmsAttribute *>(cppSelf)->::Akonadi::BlockAlarmsAttribute::type()
            : const_cast<const ::Akonadi::BlockAlarmsAttribute *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_Akonadi_BlockAlarmsAttribute_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_Akonadi_BlockAlarmsAttribute_methods[] = {
    {"blockAlarmType", reinterpret_cast<PyCFunction>(Sbk_Akonadi_BlockAlarmsAttributeFunc_blockAlarmType), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"blockEverything", reinterpret_cast<PyCFunction>(Sbk_Akonadi_BlockAlarmsAttributeFunc_blockEverything), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"clone", reinterpret_cast<PyCFunction>(Sbk_Akonadi_BlockAlarmsAttributeFunc_clone), METH_NOARGS, nullptr},
    {"deserialize", reinterpret_cast<PyCFunction>(Sbk_Akonadi_BlockAlarmsAttributeFunc_deserialize), METH_O, nullptr},
    {"isAlarmTypeBlocked", reinterpret_cast<PyCFunction>(Sbk_Akonadi_BlockAlarmsAttributeFunc_isAlarmTypeBlocked), METH_O, nullptr},
    {"isEverythingBlocked", reinterpret_cast<PyCFunction>(Sbk_Akonadi_BlockAlarmsAttributeFunc_isEverythingBlocked), METH_NOARGS, nullptr},
    {"serialized", reinterpret_cast<PyCFunction>(Sbk_Akonadi_BlockAlarmsAttributeFunc_serialized), METH_NOARGS, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_Akonadi_BlockAlarmsAttributeFunc_type), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Akonadi_BlockAlarmsAttribute_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Akonadi::BlockAlarmsAttribute *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkAkonadiCalendarTypeStructs[SBK_Akonadi_BlockAlarmsAttribute_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<BlockAlarmsAttributeWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Akonadi_BlockAlarmsAttribute_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Akonadi_BlockAlarmsAttribute_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}

// Class Definition -----------------------------------------------
extern "C" {

static PyType_Slot Sbk_Akonadi_BlockAlarmsAttribute_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Akonadi_BlockAlarmsAttribute_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Akonadi_BlockAlarmsAttribute_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Akonadi_BlockAlarmsAttribute_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Akonadi_BlockAlarmsAttribute_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_Akonadi_BlockAlarmsAttribute_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Akonadi_BlockAlarmsAttribute_spec = {
    "1:AkonadiCalendar.Akonadi.BlockAlarmsAttribute",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Akonadi_BlockAlarmsAttribute_slots
};

} //extern "C"

static void *Sbk_Akonadi_BlockAlarmsAttribute_typeDiscovery([[maybe_unused]] void *cptr, [[maybe_unused]] PyTypeObject *instanceType)
{
    if (instanceType == Shiboken::SbkType< ::Akonadi::Attribute >())
        return dynamic_cast< ::Akonadi::BlockAlarmsAttribute *>(reinterpret_cast< ::Akonadi::Attribute *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void BlockAlarmsAttribute_PythonToCpp_BlockAlarmsAttribute_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Akonadi_BlockAlarmsAttribute_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_BlockAlarmsAttribute_PythonToCpp_BlockAlarmsAttribute_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Akonadi_BlockAlarmsAttribute_TypeF()))
        return BlockAlarmsAttribute_PythonToCpp_BlockAlarmsAttribute_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *BlockAlarmsAttribute_PTR_CppToPython_BlockAlarmsAttribute(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn, Sbk_Akonadi_BlockAlarmsAttribute_TypeF()));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::Akonadi::BlockAlarmsAttribute *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_Akonadi_BlockAlarmsAttribute_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Akonadi_BlockAlarmsAttribute_SignatureStrings[] = {
    "AkonadiCalendar.Akonadi.BlockAlarmsAttribute(self)",
    "AkonadiCalendar.Akonadi.BlockAlarmsAttribute.blockAlarmType(self,type:KCalendarCore.KCalendarCore.Alarm.Type,block:bool=true)",
    "AkonadiCalendar.Akonadi.BlockAlarmsAttribute.blockEverything(self,block:bool=true)",
    "AkonadiCalendar.Akonadi.BlockAlarmsAttribute.clone(self)->AkonadiCalendar.Akonadi.BlockAlarmsAttribute",
    "AkonadiCalendar.Akonadi.BlockAlarmsAttribute.deserialize(self,data:typing.Union[PySide6.QtCore.QByteArray, char*])",
    "AkonadiCalendar.Akonadi.BlockAlarmsAttribute.isAlarmTypeBlocked(self,type:KCalendarCore.KCalendarCore.Alarm.Type)->bool",
    "AkonadiCalendar.Akonadi.BlockAlarmsAttribute.isEverythingBlocked(self)->bool",
    "AkonadiCalendar.Akonadi.BlockAlarmsAttribute.serialized(self)->PySide6.QtCore.QByteArray",
    "AkonadiCalendar.Akonadi.BlockAlarmsAttribute.type(self)->PySide6.QtCore.QByteArray",
    nullptr}; // Sentinel
#else
static constexpr size_t Akonadi_BlockAlarmsAttribute_SignatureByteSize = 219;
static constexpr uint8_t Akonadi_BlockAlarmsAttribute_SignatureBytes[219] = {
    0x78, 0xda, 0xa5, 0x92, 0x4f, 0x0f, 0x01, 0x31, 0x10, 0xc5, 0xef, 0x3e, 0x85, 0x23, 0xb2, 0x7a,
    0x74, 0xd8, 0x84, 0xa4, 0xc4, 0xc9, 0x85, 0xe0, 0x24, 0x0e, 0xb3, 0xdb, 0x41, 0xa3, 0x5a, 0x99,
    0x1d, 0x92, 0xfa, 0xf4, 0xf6, 0x9f, 0xc5, 0x81, 0xa4, 0xdc, 0x3a, 0x9d, 0xbe, 0xf7, 0x32, 0xbf,
    0xa9, 0x3c, 0x3a, 0x0b, 0x4a, 0x4f, 0xc0, 0xa0, 0x55, 0x40, 0x42, 0x56, 0xb5, 0x18, 0x1b, 0x97,
    0x1e, 0xa5, 0x01, 0x3a, 0x65, 0x92, 0x99, 0x74, 0x72, 0x61, 0xec, 0x64, 0x68, 0x76, 0xdd, 0x96,
    0x0c, 0x90, 0x88, 0xa4, 0xb9, 0x5c, 0xf9, 0x73, 0xe5, 0x10, 0x71, 0x7e, 0x8a, 0x67, 0x0f, 0xfd,
    0xc4, 0x11, 0x8a, 0xf7, 0xaa, 0x7c, 0x2f, 0x0a, 0x41, 0x54, 0xea, 0xe3, 0xc4, 0x39, 0x33, 0x64,
    0xba, 0xe0, 0x2f, 0xe9, 0xd3, 0x2b, 0x92, 0xe7, 0x83, 0xb6, 0xfb, 0x2a, 0xfe, 0x3f, 0xcb, 0xd4,
    0x38, 0x5b, 0x93, 0xe8, 0x8f, 0x42, 0x94, 0x61, 0x31, 0x0a, 0x33, 0x24, 0x0d, 0x46, 0xdf, 0x6a,
    0x68, 0x0a, 0x18, 0xe2, 0x9c, 0x5c, 0x3e, 0x86, 0x58, 0x5b, 0xed, 0xec, 0x66, 0xee, 0x97, 0x5a,
    0xe1, 0x40, 0x2c, 0xb8, 0x84, 0xb6, 0x18, 0x7b, 0x46, 0x49, 0x04, 0x3e, 0x6a, 0xa7, 0x07, 0xa0,
    0xde, 0x36, 0x70, 0x32, 0x9d, 0x35, 0x7b, 0x2a, 0xfb, 0xa8, 0x82, 0xd7, 0x95, 0x23, 0x29, 0xb8,
    0x86, 0xe6, 0x3e, 0x37, 0xf4, 0x1a, 0xfc, 0x93, 0x59, 0x43, 0xad, 0xf1, 0xf8, 0x88, 0x29, 0xcc,
    0x98, 0x1f, 0xdf, 0xf7, 0xab, 0xe5, 0x1d, 0x4e, 0x4c, 0x3a, 0x6a
};
#endif

PyTypeObject *init_Akonadi_BlockAlarmsAttribute(PyObject *enclosingClass)
{
    auto &typeStruct = SbkAkonadiCalendarTypeStructs[SBK_Akonadi_BlockAlarmsAttribute_IDX];
    if (typeStruct.type != nullptr)
        return typeStruct.type;

    auto *base1 = reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkAkonadiCoreTypeStructs[SBK_Akonadi_Attribute_IDX]));
    Shiboken::AutoDecRef Sbk_Akonadi_BlockAlarmsAttribute_Type_bases(PyTuple_Pack(1, base1));

    PyTypeObject *pyType = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "BlockAlarmsAttribute",
        "Akonadi::BlockAlarmsAttribute*",
        &Sbk_Akonadi_BlockAlarmsAttribute_spec,
        &Shiboken::callCppDestructor< Akonadi::BlockAlarmsAttribute >,
        Sbk_Akonadi_BlockAlarmsAttribute_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Akonadi_BlockAlarmsAttribute_SignatureStrings);
#else
    InitSignatureBytes(pyType, Akonadi_BlockAlarmsAttribute_SignatureBytes, Akonadi_BlockAlarmsAttribute_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Akonadi_BlockAlarmsAttribute_PropertyStrings);
    typeStruct.type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        BlockAlarmsAttribute_PythonToCpp_BlockAlarmsAttribute_PTR,
        is_BlockAlarmsAttribute_PythonToCpp_BlockAlarmsAttribute_PTR_Convertible,
        BlockAlarmsAttribute_PTR_CppToPython_BlockAlarmsAttribute);

    Shiboken::Conversions::registerConverterName(converter, "Akonadi::BlockAlarmsAttribute");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::BlockAlarmsAttribute*");
    Shiboken::Conversions::registerConverterName(converter, "Akonadi::BlockAlarmsAttribute&");
    Shiboken::Conversions::registerConverterAlias(converter, "BlockAlarmsAttribute");
    Shiboken::Conversions::registerConverterAlias(converter, "BlockAlarmsAttribute*");
    Shiboken::Conversions::registerConverterAlias(converter, "BlockAlarmsAttribute&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Akonadi::BlockAlarmsAttribute).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(BlockAlarmsAttributeWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(pyType, &Sbk_Akonadi_BlockAlarmsAttribute_typeDiscovery);

    qRegisterMetaType< ::Akonadi::BlockAlarmsAttribute *>();

    return pyType;
}
